@@ -14,7 +14,7 @@ Tools for the manipulation of point vector data.
 
 from PySAGA.helper import Tool_Wrapper
 
-def Construct_Points_from_Table(TABLE=None, POINTS=None, X=None, Y=None, Z=None, CRS_PROJ=None, CRS_CODE=None, CRS_AUTHORITY=None, Verbose=2):
+def Construct_Points_from_Table(TABLE=None, POINTS=None, X=None, Y=None, Z=None, CRS_STRING=None, Verbose=2):
     '''
     Construct Points from Table
     ----------
@@ -27,9 +27,7 @@ def Construct_Points_from_Table(TABLE=None, POINTS=None, X=None, Y=None, Z=None,
     - X [`table field`] : X
     - Y [`table field`] : Y
     - Z [`table field`] : Z
-    - CRS_PROJ [`text`] : PROJ Parameters
-    - CRS_CODE [`integer number`] : Code ID. Default: -1
-    - CRS_AUTHORITY [`text`] : Code Authority. Default: EPSG
+    - CRS_STRING [`text`] : Coordinate System Definition. Supported formats comprise PROJ and WKT strings, object codes (e.g. "EPSG:4326").
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
     Returns
@@ -43,13 +41,11 @@ def Construct_Points_from_Table(TABLE=None, POINTS=None, X=None, Y=None, Z=None,
         Tool.Set_Option('X', X)
         Tool.Set_Option('Y', Y)
         Tool.Set_Option('Z', Z)
-        Tool.Set_Option('CRS_PROJ', CRS_PROJ)
-        Tool.Set_Option('CRS_CODE', CRS_CODE)
-        Tool.Set_Option('CRS_AUTHORITY', CRS_AUTHORITY)
+        Tool.Set_Option('CRS_STRING', CRS_STRING)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_points_0(TABLE=None, POINTS=None, X=None, Y=None, Z=None, CRS_PROJ=None, CRS_CODE=None, CRS_AUTHORITY=None, Verbose=2):
+def run_tool_shapes_points_0(TABLE=None, POINTS=None, X=None, Y=None, Z=None, CRS_STRING=None, Verbose=2):
     '''
     Construct Points from Table
     ----------
@@ -62,9 +58,7 @@ def run_tool_shapes_points_0(TABLE=None, POINTS=None, X=None, Y=None, Z=None, CR
     - X [`table field`] : X
     - Y [`table field`] : Y
     - Z [`table field`] : Z
-    - CRS_PROJ [`text`] : PROJ Parameters
-    - CRS_CODE [`integer number`] : Code ID. Default: -1
-    - CRS_AUTHORITY [`text`] : Code Authority. Default: EPSG
+    - CRS_STRING [`text`] : Coordinate System Definition. Supported formats comprise PROJ and WKT strings, object codes (e.g. "EPSG:4326").
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
     Returns
@@ -78,9 +72,7 @@ def run_tool_shapes_points_0(TABLE=None, POINTS=None, X=None, Y=None, Z=None, CR
         Tool.Set_Option('X', X)
         Tool.Set_Option('Y', Y)
         Tool.Set_Option('Z', Z)
-        Tool.Set_Option('CRS_PROJ', CRS_PROJ)
-        Tool.Set_Option('CRS_CODE', CRS_CODE)
-        Tool.Set_Option('CRS_AUTHORITY', CRS_AUTHORITY)
+        Tool.Set_Option('CRS_STRING', CRS_STRING)
         return Tool.Execute(Verbose)
     return False
 
@@ -184,7 +176,7 @@ def run_tool_shapes_points_2(POINTS=None, X_EXTENT=None, Y_EXTENT=None, DIST=Non
         return Tool.Execute(Verbose)
     return False
 
-def Point_to_Point_Distances(POINTS=None, NEAR=None, DISTANCES=None, LINES=None, ID_POINTS=None, ID_NEAR=None, FORMAT=None, MAX_DIST=None, Verbose=2):
+def Point_to_Point_Distances(POINTS=None, NEAR=None, DISTANCES=None, LINES=None, ID_POINTS=None, ID_NEAR=None, FORMAT=None, MIN_DIST=None, MAX_DIST=None, Verbose=2):
     '''
     Point to Point Distances
     ----------
@@ -199,6 +191,7 @@ def Point_to_Point_Distances(POINTS=None, NEAR=None, DISTANCES=None, LINES=None,
     - ID_POINTS [`table field`] : Identifier
     - ID_NEAR [`table field`] : Identifier
     - FORMAT [`choice`] : Output Format. Available Choices: [0] complete input times near points matrix [1] each pair with a single record [2] find only the nearest point for each input point Default: 1
+    - MIN_DIST [`floating point number`] : Minimum Distance. Minimum: 0.000000 Default: 0.000000
     - MAX_DIST [`floating point number`] : Maximum Distance. Minimum: 0.000000 Default: 0.000000 ignored if set to zero (consider all pairs)
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
@@ -215,11 +208,12 @@ def Point_to_Point_Distances(POINTS=None, NEAR=None, DISTANCES=None, LINES=None,
         Tool.Set_Option('ID_POINTS', ID_POINTS)
         Tool.Set_Option('ID_NEAR', ID_NEAR)
         Tool.Set_Option('FORMAT', FORMAT)
+        Tool.Set_Option('MIN_DIST', MIN_DIST)
         Tool.Set_Option('MAX_DIST', MAX_DIST)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_points_3(POINTS=None, NEAR=None, DISTANCES=None, LINES=None, ID_POINTS=None, ID_NEAR=None, FORMAT=None, MAX_DIST=None, Verbose=2):
+def run_tool_shapes_points_3(POINTS=None, NEAR=None, DISTANCES=None, LINES=None, ID_POINTS=None, ID_NEAR=None, FORMAT=None, MIN_DIST=None, MAX_DIST=None, Verbose=2):
     '''
     Point to Point Distances
     ----------
@@ -234,6 +228,7 @@ def run_tool_shapes_points_3(POINTS=None, NEAR=None, DISTANCES=None, LINES=None,
     - ID_POINTS [`table field`] : Identifier
     - ID_NEAR [`table field`] : Identifier
     - FORMAT [`choice`] : Output Format. Available Choices: [0] complete input times near points matrix [1] each pair with a single record [2] find only the nearest point for each input point Default: 1
+    - MIN_DIST [`floating point number`] : Minimum Distance. Minimum: 0.000000 Default: 0.000000
     - MAX_DIST [`floating point number`] : Maximum Distance. Minimum: 0.000000 Default: 0.000000 ignored if set to zero (consider all pairs)
 
     - Verbose [`integer number`] : Verbosity level, 0=silent, 1=tool name and success notification, 2=complete tool output.\n
@@ -250,6 +245,7 @@ def run_tool_shapes_points_3(POINTS=None, NEAR=None, DISTANCES=None, LINES=None,
         Tool.Set_Option('ID_POINTS', ID_POINTS)
         Tool.Set_Option('ID_NEAR', ID_NEAR)
         Tool.Set_Option('FORMAT', FORMAT)
+        Tool.Set_Option('MIN_DIST', MIN_DIST)
         Tool.Set_Option('MAX_DIST', MAX_DIST)
         return Tool.Execute(Verbose)
     return False
