@@ -28,7 +28,7 @@ def Analytical_Hillshading(ELEVATION=None, SHADE=None, METHOD=None, POSITION=Non
     - POSITION [`choice`] : Sun's Position. Available Choices: [0] azimuth and height [1] date and time Default: 0
     - AZIMUTH [`floating point number`] : Azimuth. Minimum: 0.000000 Maximum: 360.000000 Default: 315.000000 Direction of the light source, measured in degree clockwise from the North direction.
     - DECLINATION [`floating point number`] : Height. Minimum: 0.000000 Maximum: 90.000000 Default: 45.000000 Height of the light source, measured in degree above the horizon.
-    - DATE [`date`] : Day. Default: 2024-10-23
+    - DATE [`date`] : Day. Default: 2024-12-03
     - TIME [`floating point number`] : Hour. Minimum: 0.000000 Maximum: 24.000000 Default: 12.000000
     - EXAGGERATION [`floating point number`] : Exaggeration. Default: 1.000000 The terrain exaggeration factor allows one to increase the shading contrasts in flat areas.
     - UNIT [`choice`] : Unit. Available Choices: [0] radians [1] degree Default: 0
@@ -73,7 +73,7 @@ def run_tool_ta_lighting_0(ELEVATION=None, SHADE=None, METHOD=None, POSITION=Non
     - POSITION [`choice`] : Sun's Position. Available Choices: [0] azimuth and height [1] date and time Default: 0
     - AZIMUTH [`floating point number`] : Azimuth. Minimum: 0.000000 Maximum: 360.000000 Default: 315.000000 Direction of the light source, measured in degree clockwise from the North direction.
     - DECLINATION [`floating point number`] : Height. Minimum: 0.000000 Maximum: 90.000000 Default: 45.000000 Height of the light source, measured in degree above the horizon.
-    - DATE [`date`] : Day. Default: 2024-10-23
+    - DATE [`date`] : Day. Default: 2024-12-03
     - TIME [`floating point number`] : Hour. Minimum: 0.000000 Maximum: 24.000000 Default: 12.000000
     - EXAGGERATION [`floating point number`] : Exaggeration. Default: 1.000000 The terrain exaggeration factor allows one to increase the shading contrasts in flat areas.
     - UNIT [`choice`] : Unit. Available Choices: [0] radians [1] degree Default: 0
@@ -129,13 +129,13 @@ def Potential_Incoming_Solar_Radiation(GRD_DEM=None, GRD_SVF=None, GRD_VAPOUR=No
     - GRD_LINKE_DEFAULT [`floating point number`] : Default. Minimum: 0.000000 Default: 3.000000 default value if no grid has been selected
     - SOLARCONST [`floating point number`] : Solar Constant [W/m²]. Minimum: 0.000000 Default: 1367.000000
     - LOCALSVF [`boolean`] : Local Sky View Factor. Default: 1 Use sky view factor based on local slope (after Oke 1988), if no sky viev factor grid is given.
-    - UNITS [`choice`] : Units. Available Choices: [0] kWh/mÂ² [1] kJ/mÂ² [2] J/cmÂ² Default: 0 Units for output radiation values.
+    - UNITS [`choice`] : Units. Available Choices: [0] kWh/m² [1] kJ/m² [2] J/cm² Default: 0 Units for output radiation values.
     - SHADOW [`choice`] : Shadow. Available Choices: [0] slim [1] fat [2] none Default: 1 Choose 'slim' to trace grid node's shadow, 'fat' to trace the whole cell's shadow, or ignore shadowing effects. The first is slightly faster but might show some artifacts.
     - LOCATION [`choice`] : Location. Available Choices: [0] constant latitude [1] calculate from grid system Default: 0
     - LATITUDE [`degree`] : Latitude. Minimum: -90.000000 Maximum: 90.000000 Default: 53.000000
     - PERIOD [`choice`] : Time Period. Available Choices: [0] moment [1] day [2] range of days Default: 1 Momentum output will be in units of power [W/m²], time span will be in units of energy, either [kWh/m²], [kJ/m²], or [J/cm²].
-    - DAY [`date`] : Day. Default: 2024-10-23
-    - DAY_STOP [`date`] : Last Day. Default: 2024-10-23
+    - DAY [`date`] : Day. Default: 2024-12-03
+    - DAY_STOP [`date`] : Last Day. Default: 2024-12-03
     - DAYS_STEP [`integer number`] : Resolution [d]. Minimum: 1 Default: 5 Time step size for a range of days calculation given in days.
     - MOMENT [`floating point number`] : Moment [h]. Minimum: 0.000000 Maximum: 24.000000 Default: 12.000000
     - HOUR_RANGE [`value range`] : Time Span [h]. Time span used for the calculation of daily radiation sums.
@@ -215,13 +215,13 @@ def run_tool_ta_lighting_2(GRD_DEM=None, GRD_SVF=None, GRD_VAPOUR=None, GRD_LINK
     - GRD_LINKE_DEFAULT [`floating point number`] : Default. Minimum: 0.000000 Default: 3.000000 default value if no grid has been selected
     - SOLARCONST [`floating point number`] : Solar Constant [W/m²]. Minimum: 0.000000 Default: 1367.000000
     - LOCALSVF [`boolean`] : Local Sky View Factor. Default: 1 Use sky view factor based on local slope (after Oke 1988), if no sky viev factor grid is given.
-    - UNITS [`choice`] : Units. Available Choices: [0] kWh/mÂ² [1] kJ/mÂ² [2] J/cmÂ² Default: 0 Units for output radiation values.
+    - UNITS [`choice`] : Units. Available Choices: [0] kWh/m² [1] kJ/m² [2] J/cm² Default: 0 Units for output radiation values.
     - SHADOW [`choice`] : Shadow. Available Choices: [0] slim [1] fat [2] none Default: 1 Choose 'slim' to trace grid node's shadow, 'fat' to trace the whole cell's shadow, or ignore shadowing effects. The first is slightly faster but might show some artifacts.
     - LOCATION [`choice`] : Location. Available Choices: [0] constant latitude [1] calculate from grid system Default: 0
     - LATITUDE [`degree`] : Latitude. Minimum: -90.000000 Maximum: 90.000000 Default: 53.000000
     - PERIOD [`choice`] : Time Period. Available Choices: [0] moment [1] day [2] range of days Default: 1 Momentum output will be in units of power [W/m²], time span will be in units of energy, either [kWh/m²], [kJ/m²], or [J/cm²].
-    - DAY [`date`] : Day. Default: 2024-10-23
-    - DAY_STOP [`date`] : Last Day. Default: 2024-10-23
+    - DAY [`date`] : Day. Default: 2024-12-03
+    - DAY_STOP [`date`] : Last Day. Default: 2024-12-03
     - DAYS_STEP [`integer number`] : Resolution [d]. Minimum: 1 Default: 5 Time step size for a range of days calculation given in days.
     - MOMENT [`floating point number`] : Moment [h]. Minimum: 0.000000 Maximum: 24.000000 Default: 12.000000
     - HOUR_RANGE [`value range`] : Time Span [h]. Time span used for the calculation of daily radiation sums.
