@@ -1242,6 +1242,7 @@ SAGA_API_DLL_EXPORT CSG_String		SG_File_Get_Path_Absolute	(const CSG_String &ful
 SAGA_API_DLL_EXPORT CSG_String		SG_File_Get_Path_Relative	(const CSG_String &Directory, const CSG_String &full_Path);
 SAGA_API_DLL_EXPORT CSG_String		SG_File_Make_Path			(const CSG_String &Directory, const CSG_String &Name);
 SAGA_API_DLL_EXPORT CSG_String		SG_File_Make_Path			(const CSG_String &Directory, const CSG_String &Name, const CSG_String &Extension);
+SAGA_API_DLL_EXPORT bool			SG_File_Cmp_Path			(const CSG_String &Path1, const CSG_String &Path2);
 SAGA_API_DLL_EXPORT bool			SG_File_Cmp_Extension		(const CSG_String &FileName, const CSG_String &Extension);
 SAGA_API_DLL_EXPORT CSG_String		SG_File_Get_Extension		(const CSG_String &FileName);
 SAGA_API_DLL_EXPORT bool			SG_File_Set_Extension		(      CSG_String &FileName, const CSG_String &Extension);
@@ -1328,7 +1329,7 @@ enum ESG_Colors
 SAGA_API_DLL_EXPORT CSG_String		SG_Colors_Get_Name	(int Index);
 
 SAGA_API_DLL_EXPORT long			SG_Color_Get_Random	(void);
-
+SAGA_API_DLL_EXPORT long			SG_Color_From_RGB	(int Red, int Green, int Blue, int Alpha = 0);
 SAGA_API_DLL_EXPORT bool			SG_Color_From_Text	(const CSG_String &Text, long &Color);
 SAGA_API_DLL_EXPORT CSG_String		SG_Color_To_Text	(long Color, bool bHexadecimal = true);
 
@@ -1570,6 +1571,7 @@ typedef enum
 	CALLBACK_MESSAGE_ADD_EXECUTION,
 
 	CALLBACK_DATAOBJECT_ADD,
+	CALLBACK_DATAOBJECT_DEL,
 	CALLBACK_DATAOBJECT_UPDATE,
 	CALLBACK_DATAOBJECT_SHOW,
 	CALLBACK_DATAOBJECT_ASIMAGE,
@@ -1671,6 +1673,7 @@ SAGA_API_DLL_EXPORT void					SG_UI_ProgressAndMsg_Lock	(bool bOn);
 SAGA_API_DLL_EXPORT void					SG_UI_ProgressAndMsg_Reset	(void);
 
 SAGA_API_DLL_EXPORT bool					SG_UI_DataObject_Add		(class CSG_Data_Object *pDataObject, int Show);
+SAGA_API_DLL_EXPORT bool					SG_UI_DataObject_Del		(class CSG_Data_Object *pDataObject, bool bConfirm);
 SAGA_API_DLL_EXPORT bool					SG_UI_DataObject_Update		(class CSG_Data_Object *pDataObject, int Show, class CSG_Parameters *pParameters);
 SAGA_API_DLL_EXPORT bool					SG_UI_DataObject_Show		(class CSG_Data_Object *pDataObject, int Show);
 SAGA_API_DLL_EXPORT bool					SG_UI_DataObject_asImage	(class CSG_Data_Object *pDataObject, class CSG_Grid *pGrid);
@@ -1691,6 +1694,8 @@ SAGA_API_DLL_EXPORT int						SG_UI_Window_Arrange		(int Arrange);
 SAGA_API_DLL_EXPORT void *					SG_UI_Get_Window_Main		(void);
 SAGA_API_DLL_EXPORT CSG_String				SG_UI_Get_Application_Path	(bool bPathOnly = false);
 SAGA_API_DLL_EXPORT CSG_String				SG_UI_Get_Application_Name	(void);
+SAGA_API_DLL_EXPORT CSG_String				SG_UI_Set_Application_Name	(const CSG_String &Name = "");
+SAGA_API_DLL_EXPORT CSG_String				SG_UI_Get_API_Path			(void);
 
 
 ///////////////////////////////////////////////////////////
@@ -1700,7 +1705,7 @@ SAGA_API_DLL_EXPORT CSG_String				SG_UI_Get_Application_Name	(void);
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-SAGA_API_DLL_EXPORT bool					SG_Initialize_Environment	(bool bLibraries = true, bool bProjections = true, const SG_Char *Directory = NULL, bool bInitializeWX = true);
+SAGA_API_DLL_EXPORT bool					SG_Initialize_Environment	(bool bLibraries = true, bool bProjections = true, const SG_Char *SAGA_Path = NULL, bool bInitializeWX = true);
 SAGA_API_DLL_EXPORT bool					SG_Uninitialize_Environment	(void);
 
 
