@@ -133,9 +133,17 @@ wxString	Get_FilePath_Relative(const wxString &Directory, const wxString &FileNa
 }
 
 //---------------------------------------------------------
-wxString	Get_FilePath_Absolute(const wxString &Directory, const wxString &FileName)
+wxString	Get_FilePath_Absolute(const wxString &Directory, const wxString &_FileName)
 {
-	wxFileName	fn(FileName);
+	wxString FileName(_FileName);
+
+	#ifdef _SAGA_MSW
+	FileName.Replace("/", "\\");
+	#else
+	FileName.Replace("\\", "/");
+	#endif
+
+	wxFileName fn(FileName);
 
 	if( !fn.IsAbsolute() )
 	{
@@ -155,13 +163,13 @@ wxString	Get_FilePath_Absolute(const wxString &Directory, const wxString &FileNa
 //---------------------------------------------------------
 wxString		Get_TableInfo_asHTML(const CSG_Table *pTable)
 {
-	wxString	s;
+	wxString s;
 
 	if( pTable && pTable->is_Valid() )
 	{
-		s	+= wxString::Format("<hr><h4>%s</h4>", _TL("Table Description"));
+		s += wxString::Format("<hr><h4>%s</h4>", _TL("Table Description"));
 
-		s	+= wxString::Format("<table border=\"1\"><tr><th>%s</th><th>%s</th><th>%s</th><th>%s</th><th>%s</th><th>%s</th><th>%s</th>",
+		s += wxString::Format("<table border=\"1\"><tr><th>%s</th><th>%s</th><th>%s</th><th>%s</th><th>%s</th><th>%s</th><th>%s</th>",
 			_TL("Field"),
 			_TL("Name"),
 			_TL("Type"),
@@ -171,9 +179,11 @@ wxString		Get_TableInfo_asHTML(const CSG_Table *pTable)
 			_TL("Standard Deviation")
 		);
 
-		for(int i=0; i<pTable->Get_Field_Count(); i++)
+		int nFields = pTable->Get_Field_Count() > 128 ? 128 : pTable->Get_Field_Count();
+
+		for(int i=0; i<nFields; i++)
 		{
-			s	+= wxString::Format("<tr><td>%d</td><td>%s</td><td>%s</td>",
+			s += wxString::Format("<tr><td>%d</td><td>%s</td><td>%s</td>",
 				i + 1,
 				pTable->Get_Field_Name(i),
 				SG_Data_Type_Get_Name(pTable->Get_Field_Type(i)).c_str()
@@ -181,7 +191,7 @@ wxString		Get_TableInfo_asHTML(const CSG_Table *pTable)
 
 			if( SG_Data_Type_is_Numeric(pTable->Get_Field_Type(i)) )
 			{
-				s	+= wxString::Format("<td align=\"right\">%s</td><td align=\"right\">%s</td><td align=\"right\">%s</td><td align=\"right\">%s</td></tr>",
+				s += wxString::Format("<td align=\"right\">%s</td><td align=\"right\">%s</td><td align=\"right\">%s</td><td align=\"right\">%s</td></tr>",
 					SG_Get_String(pTable->Get_Minimum(i), -6).c_str(),
 					SG_Get_String(pTable->Get_Maximum(i), -6).c_str(),
 					SG_Get_String(pTable->Get_Mean   (i), -6).c_str(),
@@ -190,11 +200,20 @@ wxString		Get_TableInfo_asHTML(const CSG_Table *pTable)
 			}
 			else
 			{
-				s	+= wxString::Format("<td></td><td></td><td></td><td></td></tr>");
+				s += wxString::Format("<td></td><td></td><td></td><td></td></tr>");
 			}
 		}
 
-		s	+= "</table>";
+		if( nFields < pTable->Get_Field_Count() )
+		{
+			s += "<tr><td>..</td><td>..</td><td>..</td><td>..</td><td>..</td><td>..</td><td>..</td></tr></table>";
+
+			s += wxString::Format("<i>%s: %s [%d / %d]</i>", _TL("Notice"), _TL("Only a limited number of leading fields is listed here."), nFields, pTable->Get_Field_Count());
+		}
+		else
+		{
+			s += "</table>";
+		}
 	}
 
 	return( s );
@@ -303,24 +322,24 @@ wxColour	SYS_Get_Color(wxSystemColour index)
 }
 
 //---------------------------------------------------------
-void		SYS_Set_Color_BG(wxWindow *pWindow, wxSystemColour index)
+wxColour	SYS_Get_Color_Background(int Mode)
 {
-	if( pWindow )
+	switch( Mode )
 	{
-		pWindow->SetBackgroundColour(SYS_Get_Color(index));
+	default: return( wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOW) );
+	case  1: return( *wxWHITE ); // bright
+	case  2: return( *wxBLACK ); // dark
 	}
 }
 
 //---------------------------------------------------------
-void		SYS_Set_Color_BG_Window(wxWindow *pWindow)
+wxColour	SYS_Get_Color_Foreground(int Mode)
 {
-	if( pWindow )
+	switch( Mode )
 	{
-#if defined(__WXMSW__)
-		pWindow->SetBackgroundColour(SYS_Get_Color(wxSYS_COLOUR_WINDOW));
-#else
-		pWindow->SetBackgroundColour(*wxWHITE);
-#endif
+	default: return( wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOWTEXT) );
+	case  1: return( *wxBLACK ); // bright
+	case  2: return( *wxWHITE ); // dark
 	}
 }
 
@@ -656,36 +675,37 @@ bool		CONFIG_Read(wxConfigBase *pConfig, CSG_Parameter *pParameter)
 
 	switch( pParameter->Get_Type() )
 	{
-	case PARAMETER_TYPE_Bool    :
-	case PARAMETER_TYPE_Int     :
-	case PARAMETER_TYPE_Choice  :
-	case PARAMETER_TYPE_Color   :
+	case PARAMETER_TYPE_Bool      :
+	case PARAMETER_TYPE_Int       :
+	case PARAMETER_TYPE_Data_Type :
+	case PARAMETER_TYPE_Choice    :
+	case PARAMETER_TYPE_Color     :
 		return( pConfig->Read(Entry, &l) && pParameter->Set_Value((int)l) );
 
-	case PARAMETER_TYPE_Double  :
-	case PARAMETER_TYPE_Degree  :
+	case PARAMETER_TYPE_Double    :
+	case PARAMETER_TYPE_Degree    :
 		return( pConfig->Read(Entry, &d) && pParameter->Set_Value(d) );
 
-	case PARAMETER_TYPE_Date    :
-	case PARAMETER_TYPE_String  :
-	case PARAMETER_TYPE_Text    :
-	case PARAMETER_TYPE_FilePath:
-	case PARAMETER_TYPE_Choices :
+	case PARAMETER_TYPE_Date      :
+	case PARAMETER_TYPE_String    :
+	case PARAMETER_TYPE_Text      :
+	case PARAMETER_TYPE_FilePath  :
+	case PARAMETER_TYPE_Choices   :
 		return( pConfig->Read(Entry, &s) && pParameter->Set_Value((const SG_Char *)s) );
 
-	case PARAMETER_TYPE_Range   :
+	case PARAMETER_TYPE_Range     :
 		return(
 			pConfig->Read(Entry + "_LO", &d) && pParameter->asRange()->Set_Min(d)
 		&&	pConfig->Read(Entry + "_HI", &d) && pParameter->asRange()->Set_Max(d)
 		);
 
-	case PARAMETER_TYPE_Font    :
+	case PARAMETER_TYPE_Font      :
 		return(
 			pConfig->Read(Entry + "_FONT" , &s) && pParameter->Set_Value((const SG_Char *)s)
 		&&	pConfig->Read(Entry + "_COLOR", &l) && pParameter->Set_Value((int)l)
 		);
 
-	case PARAMETER_TYPE_Colors  :
+	case PARAMETER_TYPE_Colors    :
 		return( pConfig->Read(Entry, &s) && pParameter->asColors()->from_Text(&s) );
 
 	case PARAMETER_TYPE_Parameters:
@@ -720,36 +740,37 @@ bool		CONFIG_Write(wxConfigBase *pConfig, CSG_Parameter *pParameter)
 
 		switch( pParameter->Get_Type() )
 		{
-		case PARAMETER_TYPE_Bool    :
-		case PARAMETER_TYPE_Int     :
-		case PARAMETER_TYPE_Choice  :
-		case PARAMETER_TYPE_Color   :
+		case PARAMETER_TYPE_Bool      :
+		case PARAMETER_TYPE_Int       :
+		case PARAMETER_TYPE_Data_Type :
+		case PARAMETER_TYPE_Choice    :
+		case PARAMETER_TYPE_Color     :
 			return( pConfig->Write(Entry, pParameter->asInt()) );
 
-		case PARAMETER_TYPE_Double  :
-		case PARAMETER_TYPE_Degree  :
+		case PARAMETER_TYPE_Double    :
+		case PARAMETER_TYPE_Degree    :
 			return( pConfig->Write(Entry, pParameter->asDouble()) );
 
-		case PARAMETER_TYPE_Date    :
-		case PARAMETER_TYPE_String  :
-		case PARAMETER_TYPE_Text    :
-		case PARAMETER_TYPE_FilePath:
-		case PARAMETER_TYPE_Choices :
+		case PARAMETER_TYPE_Date      :
+		case PARAMETER_TYPE_String    :
+		case PARAMETER_TYPE_Text      :
+		case PARAMETER_TYPE_FilePath  :
+		case PARAMETER_TYPE_Choices   :
 			return( pConfig->Write(Entry, pParameter->asString()) );
 
-		case PARAMETER_TYPE_Range   :
+		case PARAMETER_TYPE_Range     :
 			return(
 				pConfig->Write(Entry + "_LO", pParameter->asRange()->Get_Min())
 			&&	pConfig->Write(Entry + "_HI", pParameter->asRange()->Get_Max())
 			);
 
-		case PARAMETER_TYPE_Font    :
+		case PARAMETER_TYPE_Font      :
 			return(
 				pConfig->Write(Entry + "_FONT" , (const SG_Char *)pParameter->asPointer())
 			&&	pConfig->Write(Entry + "_COLOR", pParameter->asInt())
 			);
 
-		case PARAMETER_TYPE_Colors  :
+		case PARAMETER_TYPE_Colors    :
 			{
 				CSG_String	s;
 
@@ -845,11 +866,11 @@ bool		PROCESS_Set_Busy(bool bOn, const CSG_String &Message)
 }
 
 //---------------------------------------------------------
-bool		PROGRESSBAR_Set_Position(int Position)
+bool		PROGRESSBAR_Set_Ready(void)
 {
 	if( g_pSAGA_Frame )
 	{
-		return( g_pSAGA_Frame->ProgressBar_Set_Position(Position) );
+		return( g_pSAGA_Frame->Process_Set_Okay() );
 	}
 
 	return( true );
