@@ -102,12 +102,12 @@ CWKSP_Grid::CWKSP_Grid(CSG_Grid *pGrid)
 //---------------------------------------------------------
 wxString CWKSP_Grid::Get_Description(void)
 {
-	wxString	s;
+	wxString s;
 
 	//-----------------------------------------------------
-	s	+= wxString::Format("<h4>%s</h4>", _TL("Grid"));
+	s += wxString::Format("<h4>%s</h4>", _TL("Grid"));
 
-	s	+= "<table border=\"0\">";
+	s += "<table border=\"0\">";
 
 	DESC_ADD_STR (_TL("Name"               ), m_pObject->Get_Name());
 	DESC_ADD_STR (_TL("Description"        ), m_pObject->Get_Description());
@@ -150,7 +150,7 @@ wxString CWKSP_Grid::Get_Description(void)
 		DESC_ADD_STR(_TL("File Cache"     ), _TL("activated"));
 	}
 
-	DESC_ADD_STR (_TL("Projection"        ), m_pObject->Get_Projection().Get_Description().c_str());
+	DESC_ADD_STR (_TL("Spatial Reference" ), m_pObject->Get_Projection().Get_Description().c_str());
 	DESC_ADD_STR (_TL("West"              ), SG_Get_String(Get_Grid()->Get_XMin        (), -CSG_Grid_System::Get_Precision()).c_str());
 	DESC_ADD_STR (_TL("East"              ), SG_Get_String(Get_Grid()->Get_XMax        (), -CSG_Grid_System::Get_Precision()).c_str());
 	DESC_ADD_STR (_TL("West-East"         ), SG_Get_String(Get_Grid()->Get_XRange      (), -CSG_Grid_System::Get_Precision()).c_str());
@@ -177,25 +177,28 @@ wxString CWKSP_Grid::Get_Description(void)
 		DESC_ADD_STR(_TL("Sample Size"    ), wxString::Format("%lld* (%.02f%%)", Get_Grid()->Get_Max_Samples(), Samples));
 	}
 
-	//-----------------------------------------------------
-//	s.Append(wxString::Format(wxT("<hr><b>%s</b><font size=\"-1\">"), _TL("Data History")));
-//	s.Append(Get_Grid()->Get_History().Get_HTML());
-//	s.Append(wxString::Format(wxT("</font")));
-
-	s	+= "</table>";
+	s += "</table>";
 
 	if( Samples < 100. )
 	{
-		s	+= wxString::Format("*) %s", _TL("Statistics are based on a subset of the data set. The sample size to be used can be changed in the settings."));
+		s += wxString::Format("<small>*) <i>%s", _TL("Statistics are based on a subset of the data set. The sample size to be used can be changed in the settings.</i></small>"));
 	}
 
+	s += wxString::Format("<hr><h4>%s</h4>", _TL("Coordinate System Details"));
+	s += m_pObject->Get_Projection().Get_Description(true).c_str();
+
+	//-----------------------------------------------------
+	//	s.Append(wxString::Format(wxT("<hr><b>%s</b><font size=\"-1\">"), _TL("Data History")));
+	//	s.Append(Get_Grid()->Get_History().Get_HTML());
+	//	s.Append(wxString::Format(wxT("</font")));
+
 	return( s );
 }
 
 //---------------------------------------------------------
 wxMenu * CWKSP_Grid::Get_Menu(void)
 {
-	wxMenu	*pMenu	= new wxMenu(m_pObject->Get_Name());
+	wxMenu *pMenu = new wxMenu(m_pObject->Get_Name());
 
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_WKSP_ITEM_CLOSE);
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_GRID_SHOW);
@@ -856,7 +859,7 @@ void CWKSP_Grid::_LUT_Create(void)
 	}
 
 	//-----------------------------------------------------
-	PROGRESSBAR_Set_Position(0);
+	PROGRESSBAR_Set_Ready();
 
 	if( Classes.Get_Count() > 0 )
 	{
@@ -1149,20 +1152,22 @@ bool CWKSP_Grid::Fit_Colors(const CSG_Rect &rWorld)
 //---------------------------------------------------------
 bool CWKSP_Grid::asImage(CSG_Grid *pImage)
 {
-	wxBitmap	BMP;
+	wxImage Image;
 
-	if( pImage && Get_Image_Grid(BMP) )
+	if( pImage && Get_Image(Image) )
 	{
-		wxImage	IMG(BMP.ConvertToImage());
-
 		pImage->Create(Get_Grid(), SG_DATATYPE_Int);
 
 		#pragma omp parallel for
-		for(int y=0; y<pImage->Get_NY(); y++)
+		for(int y=0; y<pImage->Get_NY(); y++) for(int x=0; x<pImage->Get_NX(); x++)
 		{
-			for(int x=0; x<pImage->Get_NX(); x++)
+			if( Image.HasAlpha() )
 			{
-				pImage->Set_Value(x, y, SG_GET_RGB(IMG.GetRed(x, y), IMG.GetGreen(x, y), IMG.GetBlue(x, y)));
+				pImage->Set_Value(x, y, SG_GET_RGBA(Image.GetRed(x, y), Image.GetGreen(x, y), Image.GetBlue(x, y), Image.GetAlpha(x, y)));
+			}
+			else
+			{
+				pImage->Set_Value(x, y, SG_GET_RGB (Image.GetRed(x, y), Image.GetGreen(x, y), Image.GetBlue(x, y)));
 			}
 		}
 
@@ -1175,51 +1180,51 @@ bool CWKSP_Grid::asImage(CSG_Grid *pImage)
 //---------------------------------------------------------
 bool CWKSP_Grid::_Save_Image(void)
 {
-	static CSG_Parameters	P(NULL, _TL("Save Grid as Image..."), _TL(""), SG_T(""));
+	static CSG_Parameters P(NULL, _TL("Save Grid as Image..."), _TL(""), SG_T(""));
 
 	if( P.Get_Count() == 0 )
 	{
-		P.Add_Bool  ("", "WORLD", _TL("Save Georeference"), _TL(""), true);
-		P.Add_Bool  ("", "LG"   , _TL("Legend: Save"     ), _TL(""), true);
+		P.Add_Bool  ("", "WORLD", _TL("Save Georeference"), _TL(""),  true);
+		P.Add_Bool  ("", "LG"   , _TL("Legend: Save"     ), _TL(""), false);
 		P.Add_Double("", "LZ"   , _TL("Legend: Zoom"     ), _TL(""), 1., 0., true);
 	}
 
 	//-----------------------------------------------------
-	int			Type;
-	wxString	File;
-	wxBitmap	Bitmap;
+	wxString File; int Type; wxImage Image;
 
-	if( !DLG_Image_Save(File, Type) || !DLG_Parameters(&P) || !Get_Image_Grid(Bitmap) )
+	if( !DLG_Image_Save(File, Type) || !DLG_Parameters(&P) || !Get_Image(Image) )
 	{
 		return( false );
 	}
 
-	Bitmap.SaveFile(File, (wxBitmapType)Type);
+	Image.SaveFile(File, (wxBitmapType)Type);
 
 	//-----------------------------------------------------
-	if( P("LG")->asBool() && Get_Image_Legend(Bitmap, P("LZ")->asDouble()) )
+	wxBitmap Bitmap;
+
+	if( P("LG")->asBool() && Get_Bitmap_Legend(Bitmap, P("LZ")->asDouble()) )
 	{
-		wxFileName	fn(File); fn.SetName(wxString::Format("%s_legend", fn.GetName().c_str()));
+		wxFileName fn(File); fn.SetName(wxString::Format("%s_legend", fn.GetName().c_str()));
 
 		Bitmap.SaveFile(fn.GetFullPath(), (wxBitmapType)Type);
 	}
 
 	if( P("WORLD")->asBool() )
 	{
-		wxFileName	fn(File);
+		wxFileName fn(File);
 
 		switch( Type )
 		{
-		default                : fn.SetExt("world");	break;
-		case wxBITMAP_TYPE_BMP : fn.SetExt("bpw"  );	break;
-		case wxBITMAP_TYPE_GIF : fn.SetExt("gfw"  );	break;
-		case wxBITMAP_TYPE_JPEG: fn.SetExt("jgw"  );	break;
-		case wxBITMAP_TYPE_PNG : fn.SetExt("pgw"  );	break;
-		case wxBITMAP_TYPE_PCX : fn.SetExt("pxw"  );	break;
-		case wxBITMAP_TYPE_TIF : fn.SetExt("tfw"  );	break; 
+		default                : fn.SetExt("world"); break;
+		case wxBITMAP_TYPE_BMP : fn.SetExt("bpw"  ); break;
+		case wxBITMAP_TYPE_GIF : fn.SetExt("gfw"  ); break;
+		case wxBITMAP_TYPE_JPEG: fn.SetExt("jgw"  ); break;
+		case wxBITMAP_TYPE_PNG : fn.SetExt("pgw"  ); break;
+		case wxBITMAP_TYPE_PCX : fn.SetExt("pxw"  ); break;
+		case wxBITMAP_TYPE_TIF : fn.SetExt("tfw"  ); break; 
 		}
 
-		CSG_File	Stream;
+		CSG_File Stream;
 
 		if( Stream.Open(fn.GetFullPath().wx_str(), SG_FILE_W, false) )
 		{
@@ -1238,12 +1243,11 @@ bool CWKSP_Grid::_Save_Image(void)
 //---------------------------------------------------------
 bool CWKSP_Grid::_Save_Image_Clipboard(void)
 {
-	wxBitmap	Bitmap;
+	wxBitmap Bitmap;
 
-	if( Get_Image_Grid(Bitmap) && wxTheClipboard->Open() )
+	if( Get_Bitmap(Bitmap) && wxTheClipboard->Open() )
 	{
-		wxBitmapDataObject	*pBitmap	= new wxBitmapDataObject;
-		pBitmap->SetBitmap(Bitmap);
+		wxBitmapDataObject *pBitmap = new wxBitmapDataObject(Bitmap);
 		wxTheClipboard->SetData(pBitmap);
 		wxTheClipboard->Close();
 
@@ -1254,30 +1258,20 @@ bool CWKSP_Grid::_Save_Image_Clipboard(void)
 }
 
 //---------------------------------------------------------
-bool CWKSP_Grid::Get_Image_Grid(wxBitmap &BMP, bool bFitSize)
+bool CWKSP_Grid::Get_Image(wxImage &Image, bool bFitSize, int Width, int Height)
 {
-	if( bFitSize || (BMP.GetWidth() > 0 && BMP.GetHeight() > 0) )
+	if( bFitSize || Width  < 1 ) { Width  = Get_Grid()->Get_NX(); }
+	if( bFitSize || Height < 1 ) { Height = Get_Grid()->Get_NY(); }
+
+	if( Width > 0 && Height > 0 && Image.Create(Width, Height) )
 	{
 		Set_Buisy_Cursor(true);
 
-		if( bFitSize )
-		{
-			BMP.Create(Get_Grid()->Get_NX(), Get_Grid()->Get_NY());
-		}
-
-		wxMemoryDC		dc;
-		wxRect			r(0, 0, BMP.GetWidth(), BMP.GetHeight());
-		CWKSP_Map_DC	dc_Map(Get_Extent(), r, 1., SG_GET_RGB(255, 255, 255));
+		CSG_Map_DC dc_Map(Get_Extent(), wxRect(0, 0, Width, Height), 1., -1, true);
 
 		On_Draw(dc_Map, false);
 
-		dc.SelectObject(BMP);
-		dc.SetBackground(*wxWHITE_BRUSH);
-		dc.Clear();
-
-		dc_Map.Draw(dc);
-
-		dc.SelectObject(wxNullBitmap);
+		dc_Map.Get_Image(Image);
 
 		Set_Buisy_Cursor(false);
 
@@ -1288,16 +1282,39 @@ bool CWKSP_Grid::Get_Image_Grid(wxBitmap &BMP, bool bFitSize)
 }
 
 //---------------------------------------------------------
-bool CWKSP_Grid::Get_Image_Legend(wxBitmap &BMP, double Zoom)
+bool CWKSP_Grid::Get_Bitmap(wxBitmap &Bitmap, bool bFitSize, int Width, int Height)
+{
+	if( bFitSize || Width  < 1 ) { Width  = bFitSize ? Get_Grid()->Get_NX() : Bitmap.GetWidth (); }
+	if( bFitSize || Height < 1 ) { Height = bFitSize ? Get_Grid()->Get_NY() : Bitmap.GetHeight(); }
+
+	if( Width > 0 && Height > 0 && Bitmap.Create(Width, Height) )
+	{
+		Set_Buisy_Cursor(true);
+
+		CSG_Map_DC dc_Map(Get_Extent(), Bitmap.GetSize(), 1., -1, true);
+
+		On_Draw(dc_Map, false);
+
+		dc_Map.Get_Bitmap(Bitmap);
+
+		Set_Buisy_Cursor(false);
+
+		return( true );
+	}
+
+	return( false );
+}
+
+//---------------------------------------------------------
+bool CWKSP_Grid::Get_Bitmap_Legend(wxBitmap &Bitmap, double Zoom)
 {
 	if( Zoom > 0. )
 	{
-		wxMemoryDC	dc;
-		wxSize		s(Get_Legend()->Get_Size(Zoom, 1.));
+		wxMemoryDC dc; wxSize s(Get_Legend()->Get_Size(Zoom, 1.));
 
-		BMP.Create(s.GetWidth(), s.GetHeight());
+		Bitmap.Create(s.GetWidth(), s.GetHeight());
 
-		dc.SelectObject(BMP);
+		dc.SelectObject(Bitmap);
 		dc.SetBackground(*wxWHITE_BRUSH);
 		dc.Clear();
 
@@ -1317,97 +1334,93 @@ bool CWKSP_Grid::Get_Image_Legend(wxBitmap &BMP, double Zoom)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-void CWKSP_Grid::On_Draw(CWKSP_Map_DC &dc_Map, int Flags)
+void CWKSP_Grid::On_Draw(CSG_Map_DC &dc_Map, int Flags)
 {
-	if(	Get_Extent().Intersects(dc_Map.m_rWorld) == INTERSECTION_None )
+	if(	Get_Extent().Intersects(dc_Map.rWorld()) != INTERSECTION_None )
 	{
-		return;
-	}
+		CSG_Map_DC::Mode Mode = (
+			m_pClassify->Get_Mode() == CLASSIFY_SHADE                                          ? CSG_Map_DC::Mode::Shade :
+			m_pClassify->Get_Mode() == CLASSIFY_RGB && m_Parameters("RGB_ALPHA"    )->asBool() ? CSG_Map_DC::Mode::Alpha :
+			m_pClassify->Get_Mode() != CLASSIFY_RGB && m_Parameters("DISPLAY_ALPHA")->asGrid() ? CSG_Map_DC::Mode::Alpha : CSG_Map_DC::Mode::Transparent
+		);
 
-	//-----------------------------------------------------
-	int	Mode	= m_pClassify->Get_Mode() == CLASSIFY_SHADE                                          ? IMG_MODE_SHADING
-				: m_pClassify->Get_Mode() == CLASSIFY_RGB && m_Parameters("RGB_ALPHA"    )->asBool() ? IMG_MODE_TRANSPARENT_ALPHA
-				: m_pClassify->Get_Mode() != CLASSIFY_RGB && m_Parameters("DISPLAY_ALPHA")->asGrid() ? IMG_MODE_TRANSPARENT_ALPHA
-				: IMG_MODE_TRANSPARENT;
+		if( dc_Map.Draw_Image_Begin(m_Parameters("DISPLAY_TRANSPARENCY")->asDouble() / 100., Mode) )
+		{
+			m_pAlpha   = m_Parameters("DISPLAY_ALPHA"  )->asGrid  ();
+			m_Alpha[0] = m_Parameters("ALPHA_RANGE.MIN")->asDouble();
+			m_Alpha[1] = m_Parameters("ALPHA_RANGE.MAX")->asDouble() - m_Alpha[0]; m_Alpha[1] = m_Alpha[1] ? 255. / m_Alpha[1] : 1.;
 
-	if( !dc_Map.IMG_Draw_Begin(m_Parameters("DISPLAY_TRANSPARENCY")->asDouble() / 100., Mode) )
-	{
-		return;
-	}
+			//---------------------------------------------
+			TSG_Grid_Resampling Resampling;
 
-	//-----------------------------------------------------
-	m_pAlpha   = m_Parameters("DISPLAY_ALPHA"  )->asGrid  ();
-	m_Alpha[0] = m_Parameters("ALPHA_RANGE.MIN")->asDouble();
-	m_Alpha[1] = m_Parameters("ALPHA_RANGE.MAX")->asDouble() - m_Alpha[0]; m_Alpha[1] = m_Alpha[1] ? 255. / m_Alpha[1] : 1.;
+			switch( m_Parameters(m_pClassify->Get_Mode() == CLASSIFY_LUT ? "LUT_RESAMPLING" : "DISPLAY_RESAMPLING")->asInt() )
+			{
+			default: Resampling = GRID_RESAMPLING_NearestNeighbour; break;
+			case  1: Resampling = GRID_RESAMPLING_Bilinear        ; break;
+			case  2: Resampling = GRID_RESAMPLING_BicubicSpline   ; break;
+			case  3: Resampling = GRID_RESAMPLING_BSpline         ; break;
+			}
 
-	//-----------------------------------------------------
-	TSG_Grid_Resampling	Resampling;
+			//---------------------------------------------
+			m_Shade_Mode =
+				m_Parameters("COLORS_TYPE"    )->asInt() != CLASSIFY_SHADE ?
+				m_Parameters("DISPLAY_SHADING")->asInt() : 0;
 
-	switch( m_Parameters(m_pClassify->Get_Mode() == CLASSIFY_LUT ? "LUT_RESAMPLING" : "DISPLAY_RESAMPLING")->asInt() )
-	{
-	default: Resampling = GRID_RESAMPLING_NearestNeighbour; break;
-	case  1: Resampling = GRID_RESAMPLING_Bilinear        ; break;
-	case  2: Resampling = GRID_RESAMPLING_BicubicSpline   ; break;
-	case  3: Resampling = GRID_RESAMPLING_BSpline         ; break;
-	}
+			if( m_Shade_Mode && Get_Grid()->Get_Range() > 0. )
+			{
+				//	m_Shade_Parms[0] = m_Parameters("SHADING_EXAGG")->asDouble() * Get_Grid()->Get_Cellsize() / Get_Grid()->Get_StdDev();
+				m_Shade_Parms[0] = m_Parameters("SHADING_EXAGG")->asDouble() * Get_Grid()->Get_Cellsize() / 25.;
+				m_Shade_Parms[1] = sin(M_DEG_TO_RAD * m_Parameters("SHADING_HEIGHT")->asDouble());
+				m_Shade_Parms[2] = cos(M_DEG_TO_RAD * m_Parameters("SHADING_HEIGHT")->asDouble());
+				m_Shade_Parms[3] =     M_DEG_TO_RAD * m_Parameters("SHADING_AZIMUTH")->asDouble();
+				m_Shade_Parms[4] = m_Parameters("SHADING_MIN")->asDouble();
+				m_Shade_Parms[5] = m_Parameters("SHADING_MAX")->asDouble() - m_Shade_Parms[4];
+			}
 
-	//-----------------------------------------------------
-	m_Shade_Mode	= m_Parameters("COLORS_TYPE"    )->asInt() != CLASSIFY_SHADE
-					? m_Parameters("DISPLAY_SHADING")->asInt() : 0;
+			//---------------------------------------------
+			m_pClassify->Set_Shade_Mode(m_Parameters("SHADE_MODE")->asInt());
 
-	if( m_Shade_Mode && Get_Grid()->Get_Range() > 0. )
-	{
-	//	m_Shade_Parms[0]	= m_Parameters("SHADING_EXAGG")->asDouble() * Get_Grid()->Get_Cellsize() / Get_Grid()->Get_StdDev();
-		m_Shade_Parms[0]	= m_Parameters("SHADING_EXAGG")->asDouble() * Get_Grid()->Get_Cellsize() / 25.;
-		m_Shade_Parms[1]	= sin(M_DEG_TO_RAD * m_Parameters("SHADING_HEIGHT")->asDouble());
-		m_Shade_Parms[2]	= cos(M_DEG_TO_RAD * m_Parameters("SHADING_HEIGHT")->asDouble());
-		m_Shade_Parms[3]	=     M_DEG_TO_RAD * m_Parameters("SHADING_AZIMUTH")->asDouble();
-		m_Shade_Parms[4]	= m_Parameters("SHADING_MIN")->asDouble();
-		m_Shade_Parms[5]	= m_Parameters("SHADING_MAX")->asDouble() - m_Shade_Parms[4];
-	}
+			if(	dc_Map.DC2World() >= Get_Grid()->Get_Cellsize()
+			||	Resampling != GRID_RESAMPLING_NearestNeighbour
+			||  m_Parameters("COLORS_TYPE")->asInt() == CLASSIFY_OVERLAY )
+			{
+				_Draw_Grid_Nodes(dc_Map, Resampling);
+			}
+			else
+			{
+				_Draw_Grid_Cells(dc_Map);
+			}
 
-	//-----------------------------------------------------
-	m_pClassify->Set_Shade_Mode(m_Parameters("SHADE_MODE")->asInt());
+			//---------------------------------------------
+			dc_Map.Draw_Image_End();
 
-	if(	dc_Map.m_DC2World >= Get_Grid()->Get_Cellsize()
-	||	Resampling != GRID_RESAMPLING_NearestNeighbour
-	||  m_Parameters("COLORS_TYPE")->asInt() == CLASSIFY_OVERLAY )
-	{
-		_Draw_Grid_Nodes(dc_Map, Resampling);
-	}
-	else
-	{
-		_Draw_Grid_Cells(dc_Map);
-	}
+			if( (Flags & LAYER_DRAW_FLAG_NOLABELS) == 0 )
+			{
+				_Draw_Values(dc_Map);
+			}
 
-	//-----------------------------------------------------
-	dc_Map.IMG_Draw_End();
-
-	if( (Flags & LAYER_DRAW_FLAG_NOLABELS) == 0 )
-	{
-		_Draw_Values(dc_Map);
-	}
-
-	if( (Flags & LAYER_DRAW_FLAG_NOEDITS) == 0 )
-	{
-		_Draw_Edit(dc_Map);
+			if( (Flags & LAYER_DRAW_FLAG_NOEDITS) == 0 )
+			{
+				_Draw_Edit(dc_Map);
+			}
+		}
 	}
 }
 
 //---------------------------------------------------------
-void CWKSP_Grid::_Draw_Grid_Nodes(CWKSP_Map_DC &dc_Map, TSG_Grid_Resampling Resampling)
+void CWKSP_Grid::_Draw_Grid_Nodes(CSG_Map_DC &dc_Map, TSG_Grid_Resampling Resampling)
 {
-	CSG_Grid *pOverlay[2]; CSG_Scaler	Scaler[2];
+	CSG_Grid *pOverlay[2]; CSG_Scaler Scaler[2];
 
 	_Get_Overlay(pOverlay, Scaler);
 
-	CSG_Rect	rMap(dc_Map.m_rWorld);	rMap.Intersect(Get_Grid()->Get_Extent(true));
+	CSG_Rect rMap(dc_Map.rWorld());	rMap.Intersect(Get_Grid()->Get_Extent(true));
 
-	int	axDC	= (int)dc_Map.xWorld2DC(rMap.Get_XMin());	if( axDC < 0 )	axDC	= 0;
-	int	bxDC	= (int)dc_Map.xWorld2DC(rMap.Get_XMax());	if( bxDC >= dc_Map.m_rDC.GetWidth () )	bxDC	= dc_Map.m_rDC.GetWidth () - 1;
-	int	ayDC	= (int)dc_Map.yWorld2DC(rMap.Get_YMin());	if( ayDC >= dc_Map.m_rDC.GetHeight() )	ayDC	= dc_Map.m_rDC.GetHeight() - 1;
-	int	byDC	= (int)dc_Map.yWorld2DC(rMap.Get_YMax());	if( byDC < 0 )	byDC	= 0;
-	int	nyDC	= abs(ayDC - byDC);
+	int axDC = (int)dc_Map.xWorld2DC(rMap.Get_XMin()); if( axDC <  0                        ) { axDC = 0;                            }
+	int bxDC = (int)dc_Map.xWorld2DC(rMap.Get_XMax()); if( bxDC >= dc_Map.rDC().GetWidth () ) { bxDC = dc_Map.rDC().GetWidth () - 1; }
+	int ayDC = (int)dc_Map.yWorld2DC(rMap.Get_YMin()); if( ayDC >= dc_Map.rDC().GetHeight() ) { ayDC = dc_Map.rDC().GetHeight() - 1; }
+	int byDC = (int)dc_Map.yWorld2DC(rMap.Get_YMax()); if( byDC <  0                        ) { byDC = 0;                            }
+	int nyDC = abs(ayDC - byDC);
 
 	if( Get_Grid()->is_Cached() )
 	{
@@ -1431,7 +1444,7 @@ void CWKSP_Grid::_Get_Overlay(CSG_Grid *pOverlay[2], CSG_Scaler Scaler[2])
 {
 	if( m_pClassify->Get_Mode() != CLASSIFY_OVERLAY )
 	{
-		pOverlay [0] = pOverlay [1] = NULL;
+		pOverlay[0] = pOverlay [1] = NULL;
 	}
 	else
 	{
@@ -1474,7 +1487,7 @@ void CWKSP_Grid::_Get_Overlay(CSG_Grid *pOverlay[2], CSG_Scaler Scaler[2])
 			}
 			else if( g_pData->Get(pOverlay[i]) )
 			{
-				CWKSP_Layer_Classify	*pClassify	= ((CWKSP_Layer *)g_pData->Get(pOverlay[i]))->Get_Classifier();
+				CWKSP_Layer_Classify *pClassify = ((CWKSP_Layer *)g_pData->Get(pOverlay[i]))->Get_Classifier();
 
 				Scaler[i].Create(pClassify->Get_Metric_Minimum(), pClassify->Get_Metric_Maximum(),
 					pClassify->Get_Metric_Mode() == METRIC_MODE_LOGUP   ?  pClassify->Get_Metric_LogFactor() :
@@ -1486,33 +1499,33 @@ void CWKSP_Grid::_Get_Overlay(CSG_Grid *pOverlay[2], CSG_Scaler Scaler[2])
 }
 
 //---------------------------------------------------------
-void CWKSP_Grid::_Draw_Grid_Nodes(CWKSP_Map_DC &dc_Map, TSG_Grid_Resampling Resampling, int yDC, int axDC, int bxDC, CSG_Grid *pOverlay[2], CSG_Scaler Scaler[2])
+void CWKSP_Grid::_Draw_Grid_Nodes(CSG_Map_DC &dc_Map, TSG_Grid_Resampling Resampling, int yDC, int axDC, int bxDC, CSG_Grid *pOverlay[2], CSG_Scaler Scaler[2])
 {
 	int	Overlay[3];
 
 	switch( m_Parameters("OVERLAY_MODE")->asInt() )
 	{
-	default: Overlay[0] = 0; Overlay[1] = 1; Overlay[2] = 2; break;	// this = r, pOverlay[0] = g, pOverlay[1] = r
-	case  1: Overlay[0] = 1; Overlay[1] = 0; Overlay[2] = 2; break;	// this = g, pOverlay[0] = r, pOverlay[1] = b
-	case  2: Overlay[0] = 2; Overlay[1] = 0; Overlay[2] = 1; break;	// this = b, pOverlay[0] = r, pOverlay[1] = g
+	default: Overlay[0] = 0; Overlay[1] = 1; Overlay[2] = 2; break; // this = r, pOverlay[0] = g, pOverlay[1] = r
+	case  1: Overlay[0] = 1; Overlay[1] = 0; Overlay[2] = 2; break; // this = g, pOverlay[0] = r, pOverlay[1] = b
+	case  2: Overlay[0] = 2; Overlay[1] = 0; Overlay[2] = 1; break; // this = b, pOverlay[0] = r, pOverlay[1] = g
 	}
 
-	double	xMap	= dc_Map.xDC2World(axDC);
-	double	yMap	= dc_Map.yDC2World( yDC);
+	double xMap = dc_Map.xDC2World(axDC);
+	double yMap = dc_Map.yDC2World( yDC);
 
-	for(int xDC=axDC; xDC<=bxDC; xMap+=dc_Map.m_DC2World, xDC++)
+	for(int xDC=axDC; xDC<=bxDC; xMap+=dc_Map.DC2World(), xDC++)
 	{
-		double	Value;
+		double Value;
 
 		if( Get_Grid()->Get_Value(xMap, yMap, Value, Resampling, false, m_pClassify->Get_Mode() == CLASSIFY_RGB) )
 		{
 			if( m_pClassify->Get_Mode() != CLASSIFY_OVERLAY )
 			{
-				int  Color;
+				int Color;
 
 				if( m_pClassify->Get_Class_Color_byValue(Value, Color) )
 				{
-					dc_Map.IMG_Set_Pixel(xDC, yDC, _Get_Shading(xMap, yMap, Color, Resampling));
+					dc_Map.Draw_Image_Pixel(xDC, yDC, _Get_Shading(xMap, yMap, Color, Resampling));
 				}
 			}
 			else
@@ -1528,39 +1541,39 @@ void CWKSP_Grid::_Draw_Grid_Nodes(CWKSP_Map_DC &dc_Map, TSG_Grid_Resampling Resa
 				Value = pOverlay[1] && pOverlay[1]->Get_Value(xMap, yMap, Value, Resampling) ? Scaler[1].to_Relative(Value) : 1.;
 				Color[Overlay[2]] = Value <= 0. ? 0 : Value >= 1. ? 255 : (BYTE)(255. * Value);
 
-				dc_Map.IMG_Set_Pixel(xDC, yDC, _Get_Shading(xMap, yMap, *(int *)Color, Resampling));
+				dc_Map.Draw_Image_Pixel(xDC, yDC, _Get_Shading(xMap, yMap, *(int *)Color, Resampling));
 			}
 		}
 	}
 }
 
 //---------------------------------------------------------
-void CWKSP_Grid::_Draw_Grid_Cells(CWKSP_Map_DC &dc_Map)
+void CWKSP_Grid::_Draw_Grid_Cells(CSG_Map_DC &dc_Map)
 {
-	int	xa	= Get_Grid()->Get_System().Get_xWorld_to_Grid(dc_Map.m_rWorld.Get_XMin()); if( xa <  0                    ) xa = 0;
-	int	ya	= Get_Grid()->Get_System().Get_yWorld_to_Grid(dc_Map.m_rWorld.Get_YMin()); if( ya <  0                    ) ya = 0;
-	int	xb	= Get_Grid()->Get_System().Get_xWorld_to_Grid(dc_Map.m_rWorld.Get_XMax()); if( xb >= Get_Grid()->Get_NX() ) xb = Get_Grid()->Get_NX() - 1;
-	int	yb	= Get_Grid()->Get_System().Get_yWorld_to_Grid(dc_Map.m_rWorld.Get_YMax()); if( yb >= Get_Grid()->Get_NY() ) yb = Get_Grid()->Get_NY() - 1;
+	int xa = Get_Grid()->Get_System().Get_xWorld_to_Grid(dc_Map.rWorld().Get_XMin()); if( xa <  0                    ) xa = 0;
+	int ya = Get_Grid()->Get_System().Get_yWorld_to_Grid(dc_Map.rWorld().Get_YMin()); if( ya <  0                    ) ya = 0;
+	int xb = Get_Grid()->Get_System().Get_xWorld_to_Grid(dc_Map.rWorld().Get_XMax()); if( xb >= Get_Grid()->Get_NX() ) xb = Get_Grid()->Get_NX() - 1;
+	int yb = Get_Grid()->Get_System().Get_yWorld_to_Grid(dc_Map.rWorld().Get_YMax()); if( yb >= Get_Grid()->Get_NY() ) yb = Get_Grid()->Get_NY() - 1;
 
-	double	dDC	 = Get_Grid()->Get_Cellsize() * dc_Map.m_World2DC;
+	double  dDC = Get_Grid()->Get_Cellsize() * dc_Map.World2DC();
 
-	double	axDC = dc_Map.xWorld2DC(Get_Grid()->Get_System().Get_xGrid_to_World(xa)) + dDC / 2.;
-	double	ayDC = dc_Map.yWorld2DC(Get_Grid()->Get_System().Get_yGrid_to_World(ya)) - dDC / 2.;
+	double axDC = dc_Map.xWorld2DC(Get_Grid()->Get_System().Get_xGrid_to_World(xa)) + dDC / 2.;
+	double ayDC = dc_Map.yWorld2DC(Get_Grid()->Get_System().Get_yGrid_to_World(ya)) - dDC / 2.;
 
 	//-----------------------------------------------------
-	double	yDC	= ayDC;
+	double  yDC = ayDC;
 
 	for(int y=ya, yaDC=(int)(ayDC), ybDC=(int)(ayDC+dDC); y<=yb; y++, ybDC=yaDC, yaDC=(int)(yDC-=dDC))
 	{
-		double	xDC	= axDC;
+		double xDC = axDC;
 
 		for(int x=xa, xaDC=(int)(axDC-dDC), xbDC=(int)(axDC); x<=xb; x++, xaDC=xbDC, xbDC=(int)(xDC+=dDC))
 		{
-			int	Color;
+			int Color;
 
 			if( Get_Grid()->is_InGrid(x, y) && m_pClassify->Get_Class_Color_byValue(Get_Grid()->asDouble(x, y), Color) )
 			{
-				dc_Map.IMG_Set_Rect(xaDC, yaDC, xbDC, ybDC, _Get_Shading(x, y, Color));
+				dc_Map.Draw_Image_Pixels(xaDC, yaDC, xbDC, ybDC, _Get_Shading(x, y, Color));
 			}
 		}
 	}
@@ -1569,13 +1582,13 @@ void CWKSP_Grid::_Draw_Grid_Cells(CWKSP_Map_DC &dc_Map)
 //---------------------------------------------------------
 inline void CWKSP_Grid::_Set_Shading(double Shade, int &Color)
 {
-	Shade	= m_Shade_Parms[5] * ((1. - Shade / M_PI_090) - m_Shade_Parms[4]);
+	Shade = m_Shade_Parms[5] * ((1. - Shade / M_PI_090) - m_Shade_Parms[4]);
 
-	int	r	= (int)(Shade * SG_GET_R(Color)); if( r < 0 ) r = 0; else if( r > 255 ) r = 255;
-	int	g	= (int)(Shade * SG_GET_G(Color)); if( g < 0 ) g = 0; else if( g > 255 ) g = 255;
-	int	b	= (int)(Shade * SG_GET_B(Color)); if( b < 0 ) b = 0; else if( b > 255 ) b = 255;
+	int r = (int)(Shade * SG_GET_R(Color)); if( r < 0 ) r = 0; else if( r > 255 ) r = 255;
+	int g = (int)(Shade * SG_GET_G(Color)); if( g < 0 ) g = 0; else if( g > 255 ) g = 255;
+	int b = (int)(Shade * SG_GET_B(Color)); if( b < 0 ) b = 0; else if( b > 255 ) b = 255;
 
-	Color	= SG_GET_RGB(r, g, b);
+	Color = SG_GET_RGB(r, g, b);
 }
 
 //---------------------------------------------------------
@@ -1583,11 +1596,11 @@ inline int CWKSP_Grid::_Get_Shading(int x, int y, int Color)
 {
 	if( m_Shade_Mode )
 	{
-		double	s, a;
+		double s, a;
 
 		if( Get_Grid()->Get_Gradient(x, y, s, a) )
 		{
-			s	= M_PI_090 - atan(m_Shade_Parms[0] * tan(s));
+			s = M_PI_090 - atan(m_Shade_Parms[0] * tan(s));
 
 			if( m_Shade_Mode == 1 )
 			{
@@ -1609,9 +1622,9 @@ inline int CWKSP_Grid::_Get_Shading(int x, int y, int Color)
 
 	if( m_pAlpha )
 	{
-		double	Alpha;	TSG_Point	p	= Get_Grid()->Get_System().Get_Grid_to_World(x, y);
+		CSG_Point p = Get_Grid()->Get_System().Get_Grid_to_World(x, y);
 
-		Alpha	= m_pAlpha->Get_Value(p, Alpha) ? (Alpha - m_Alpha[0]) * m_Alpha[1] : 1.;
+		double Alpha = m_pAlpha->Get_Value(p, Alpha) ? (Alpha - m_Alpha[0]) * m_Alpha[1] : 1.;
 
 		((BYTE *)&Color)[3] = Alpha <= 0. ? 0 : Alpha >= 255. ? 255 : (BYTE)Alpha;
 	}
@@ -1624,11 +1637,11 @@ inline int CWKSP_Grid::_Get_Shading(double x, double y, int Color, TSG_Grid_Resa
 {
 	if( m_Shade_Mode )
 	{
-		double	s, a;
+		double s, a;
 
 		if( Get_Grid()->Get_Gradient(x, y, s, a, Resampling) )
 		{
-			s	= M_PI_090 - atan(m_Shade_Parms[0] * tan(s));
+			s = M_PI_090 - atan(m_Shade_Parms[0] * tan(s));
 
 			if( m_Shade_Mode == 1 )
 			{
@@ -1650,9 +1663,7 @@ inline int CWKSP_Grid::_Get_Shading(double x, double y, int Color, TSG_Grid_Resa
 
 	if( m_pAlpha )
 	{
-		double	Alpha;
-		
-		Alpha	= m_pAlpha->Get_Value(x, y, Alpha, Resampling) ? (Alpha - m_Alpha[0]) * m_Alpha[1] : 1.;
+		double Alpha = m_pAlpha->Get_Value(x, y, Alpha, Resampling) ? (Alpha - m_Alpha[0]) * m_Alpha[1] : 1.;
 
 		((BYTE *)&Color)[3] = Alpha <= 0. ? 0 : Alpha >= 255. ? 255 : (BYTE)Alpha;
 	}
@@ -1661,78 +1672,73 @@ inline int CWKSP_Grid::_Get_Shading(double x, double y, int Color, TSG_Grid_Resa
 }
 
 //---------------------------------------------------------
-void CWKSP_Grid::_Draw_Values(CWKSP_Map_DC &dc_Map)
+void CWKSP_Grid::_Draw_Values(CSG_Map_DC &dc_Map)
 {
-	if(	!m_Parameters("VALUES_SHOW")->asBool() || Get_Grid()->Get_Cellsize() * dc_Map.m_World2DC <= 40 )
+	if(	!m_Parameters("VALUES_SHOW")->asBool() || Get_Grid()->Get_Cellsize() * dc_Map.World2DC() <= 40 )
 	{
 		return;
 	}
 
 	//-----------------------------------------------------
-	int			ax, ay, bx, by, Decimals, Effect;
-	double		axDC, ayDC, dDC;
-	wxColour	Effect_Color;
-	wxFont		Font;
+	double   dDC = Get_Grid()->Get_Cellsize() * dc_Map.World2DC();
+	int Decimals = m_Parameters("VALUES_DECIMALS")->asInt();
+	wxFont  Font = Get_Font(m_Parameters("VALUES_FONT")); Font.SetPointSize((int)(dDC * m_Parameters("VALUES_SIZE")->asDouble() / 100.));
+	dc_Map.SetFont(Font);
+	dc_Map.Get_DC().SetTextForeground(Get_Color_asWX(m_Parameters("VALUES_FONT")->asColor()));
 
-	dDC			= Get_Grid()->Get_Cellsize() * dc_Map.m_World2DC;
-	Decimals	= m_Parameters("VALUES_DECIMALS")->asInt();
-	Font		= Get_Font(m_Parameters("VALUES_FONT"));
-	Font.SetPointSize((int)(dDC * m_Parameters("VALUES_SIZE")->asDouble() / 100.));
-	dc_Map.dc.SetFont(Font);
-	dc_Map.dc.SetTextForeground(Get_Color_asWX(m_Parameters("VALUES_FONT")->asColor()));
+	int Effect;
 
 	switch( m_Parameters("VALUES_EFFECT")->asInt() )
 	{
-	default: Effect	= TEXTEFFECT_NONE       ;	break;
-	case  1: Effect	= TEXTEFFECT_FRAME      ;	break;
-	case  2: Effect	= TEXTEFFECT_TOP        ;	break;
-	case  3: Effect	= TEXTEFFECT_TOPLEFT    ;	break;
-	case  4: Effect	= TEXTEFFECT_LEFT       ;	break;
-	case  5: Effect	= TEXTEFFECT_BOTTOMLEFT ;	break;
-	case  6: Effect	= TEXTEFFECT_BOTTOM     ;	break;
-	case  7: Effect	= TEXTEFFECT_BOTTOMRIGHT;	break;
-	case  8: Effect	= TEXTEFFECT_RIGHT      ;	break;
-	case  9: Effect	= TEXTEFFECT_TOPRIGHT   ;	break;
+	default: Effect = TEXTEFFECT_NONE       ; break;
+	case  1: Effect = TEXTEFFECT_FRAME      ; break;
+	case  2: Effect = TEXTEFFECT_TOP        ; break;
+	case  3: Effect = TEXTEFFECT_TOPLEFT    ; break;
+	case  4: Effect = TEXTEFFECT_LEFT       ; break;
+	case  5: Effect = TEXTEFFECT_BOTTOMLEFT ; break;
+	case  6: Effect = TEXTEFFECT_BOTTOM     ; break;
+	case  7: Effect = TEXTEFFECT_BOTTOMRIGHT; break;
+	case  8: Effect = TEXTEFFECT_RIGHT      ; break;
+	case  9: Effect = TEXTEFFECT_TOPRIGHT   ; break;
 	}
 
-	Effect_Color	= m_Parameters("VALUES_EFFECT_COLOR")->asColor();
+	wxColour Effect_Color = m_Parameters("VALUES_EFFECT_COLOR")->asColor();
 
 	//-------------------------------------------------
-	ax		= Get_Grid()->Get_System().Get_xWorld_to_Grid(dc_Map.m_rWorld.Get_XMin());
-	ay		= Get_Grid()->Get_System().Get_yWorld_to_Grid(dc_Map.m_rWorld.Get_YMin());
-	bx		= Get_Grid()->Get_System().Get_xWorld_to_Grid(dc_Map.m_rWorld.Get_XMax());
-	by		= Get_Grid()->Get_System().Get_yWorld_to_Grid(dc_Map.m_rWorld.Get_YMax());
+	int ax = Get_Grid()->Get_System().Get_xWorld_to_Grid(dc_Map.rWorld().Get_XMin());
+	int ay = Get_Grid()->Get_System().Get_yWorld_to_Grid(dc_Map.rWorld().Get_YMin());
+	int bx = Get_Grid()->Get_System().Get_xWorld_to_Grid(dc_Map.rWorld().Get_XMax());
+	int by = Get_Grid()->Get_System().Get_yWorld_to_Grid(dc_Map.rWorld().Get_YMax());
 
 	if( ax < 0 ) { ax = 0; } if( bx >= Get_Grid()->Get_NX() ) { bx = Get_Grid()->Get_NX() - 1; }
 	if( ay < 0 ) { ax = 0; } if( by >= Get_Grid()->Get_NY() ) { by = Get_Grid()->Get_NY() - 1; }
 
-	axDC	= dc_Map.xWorld2DC(Get_Grid()->Get_System().Get_xGrid_to_World(ax));
-	ayDC	= dc_Map.yWorld2DC(Get_Grid()->Get_System().Get_yGrid_to_World(ay));
+	double axDC = dc_Map.xWorld2DC(Get_Grid()->Get_System().Get_xGrid_to_World(ax));
+	double ayDC = dc_Map.yWorld2DC(Get_Grid()->Get_System().Get_yGrid_to_World(ay));
 
-	int	ny	= by - ay;
+	int ny = by - ay;
 
 	//-------------------------------------------------
 	for(int y=0; y<=ny; y++)
 	{
-		int		x;
-		double	xDC, yDC	= ayDC - y * dDC;// dc_Map.m_World2DC;
+		double xDC = axDC, yDC = ayDC - y * dDC; // dc_Map.World2DC();
 
-		for(x=ax, xDC=axDC; x<=bx; x++, xDC+=dDC)
+		for(int x=ax; x<=bx; x++, xDC+=dDC)
 		{
 			if( Get_Grid()->is_InGrid(x, ay + y) )
 			{
-				double	Value	= Get_Grid()->asDouble(x, ay + y);
+				double Value = Get_Grid()->asDouble(x, ay + y);
 
 				switch( m_pClassify->Get_Mode() )
 				{
 				case CLASSIFY_RGB:
-					Draw_Text(dc_Map.dc, TEXTALIGN_CENTER, (int)xDC, (int)yDC, wxString::Format(
+					dc_Map.DrawText(TEXTALIGN_CENTER, (int)xDC, (int)yDC, wxString::Format(
 						"R%03d G%03d B%03d", SG_GET_R((int)Value), SG_GET_G((int)Value), SG_GET_B((int)Value)
 					), Effect, Effect_Color);
 					break;
 
 				default:
-					Draw_Text(dc_Map.dc, TEXTALIGN_CENTER, (int)xDC, (int)yDC, wxString::Format(
+					dc_Map.DrawText(TEXTALIGN_CENTER, (int)xDC, (int)yDC, wxString::Format(
 						"%.*f", Decimals, Value
 					), Effect, Effect_Color);
 					break;
@@ -1743,30 +1749,25 @@ void CWKSP_Grid::_Draw_Values(CWKSP_Map_DC &dc_Map)
 }
 
 //---------------------------------------------------------
-void CWKSP_Grid::_Draw_Edit(CWKSP_Map_DC &dc_Map)
+void CWKSP_Grid::_Draw_Edit(CSG_Map_DC &dc_Map)
 {
 	if( m_Edit_Attributes.Get_Count() > 0 )
 	{
-		CSG_Rect	r(
+		CSG_Rect r(
 			-Get_Grid()->Get_Cellsize() / 2. + Get_Grid()->Get_System().Get_xGrid_to_World(m_xSel),
 			-Get_Grid()->Get_Cellsize() / 2. + Get_Grid()->Get_System().Get_yGrid_to_World(m_ySel),
 			-Get_Grid()->Get_Cellsize() / 2. + Get_Grid()->Get_System().Get_xGrid_to_World(m_xSel + m_Edit_Attributes.Get_Field_Count() - 1),
 			-Get_Grid()->Get_Cellsize() / 2. + Get_Grid()->Get_System().Get_yGrid_to_World(m_ySel + m_Edit_Attributes.Get_Count())
 		);
 
-		TSG_Point_Int	a(dc_Map.World2DC(r.Get_TopLeft    ()));
-		TSG_Point_Int	b(dc_Map.World2DC(r.Get_BottomRight()));
+		TSG_Point_Int a(dc_Map.World2DC(r.Get_TopLeft    ())); a.x -= 1; a.y -= 1;
+		TSG_Point_Int b(dc_Map.World2DC(r.Get_BottomRight())); b.x -= 1; b.y -= 1;
 
-		a.x	-= 1;
-		b.x	-= 1;
-		a.y	-= 1;
-		b.y	-= 1;
-
-		dc_Map.dc.SetPen(wxPen(wxColour(255, 0, 0), 2, wxPENSTYLE_SOLID));
-		dc_Map.dc.DrawLine(a.x, a.y, a.x, b.y);
-		dc_Map.dc.DrawLine(a.x, b.y, b.x, b.y);
-		dc_Map.dc.DrawLine(b.x, b.y, b.x, a.y);
-		dc_Map.dc.DrawLine(a.x, a.y, b.x, a.y);
+		dc_Map.SetPen(wxPen(wxColour(255, 0, 0), 2, wxPENSTYLE_SOLID));
+		dc_Map.DrawLine(a.x, a.y, a.x, b.y);
+		dc_Map.DrawLine(a.x, b.y, b.x, b.y);
+		dc_Map.DrawLine(b.x, b.y, b.x, a.y);
+		dc_Map.DrawLine(a.x, a.y, b.x, a.y);
 	}
 }
 
