@@ -227,7 +227,7 @@ wxString CWKSP_Map::Get_Description(void)
 
 	DESC_ADD_STR(_TL("Name"             ), m_Name.c_str());
 	DESC_ADD_INT(_TL("Layers"           ), Get_Count());
-	DESC_ADD_STR(_TL("Coordinate System"), m_Projection.Get_Description().c_str());
+	DESC_ADD_STR(_TL("Spatial Reference"), m_Projection.Get_Description().c_str());
 
 	int n = Get_Extent().Get_Diameter() > 1 ? 0 : -99;
 
@@ -240,6 +240,9 @@ wxString CWKSP_Map::Get_Description(void)
 
 	s += "</table>";
 
+	s += wxString::Format("<hr><h4>%s</h4>", _TL("Coordinate System Details"));
+	s += m_Projection.Get_Description(true).c_str();
+
 	//-----------------------------------------------------
 	return( s );
 }
@@ -247,9 +250,9 @@ wxString CWKSP_Map::Get_Description(void)
 //---------------------------------------------------------
 wxMenu * CWKSP_Map::Get_Menu(void)
 {
-	wxMenu	*pMenu;
+	wxMenu *pMenu;
 
-	pMenu	= new wxMenu(_TL("Map"));
+	pMenu = new wxMenu(_TL("Map"));
 
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_WKSP_ITEM_CLOSE);
 	CMD_Menu_Add_Item(pMenu,  true, ID_CMD_MAPS_SHOW);
@@ -389,94 +392,107 @@ void CWKSP_Map::On_Create_Parameters(void)
 	///////////////////////////////////////////////////////
 	//-----------------------------------------------------
 	m_Parameters.Add_Node("",
-		"NODE_GENERAL"	, _TL("General"),
+		"NODE_GENERAL"  , _TL("General"),
 		_TL("")
 	);
 
 	m_Parameters.Add_String("NODE_GENERAL",
-		"NAME"			, _TL("Name"),
+		"NAME"          , _TL("Name"),
 		_TL(""),
 		&m_Name
 	);
 
+	m_Parameters.Add_Choice("NODE_GENERAL",
+		"BG_COLOR"      , _TL("Background Color"),
+		_TL(""),
+		CSG_String::Format("%s|%s", _TL("system"), _TL("user defined")),
+		g_pMaps->Get_Parameter("BG_COLOR")->asInt()
+	);
+
+	m_Parameters.Add_Color("BG_COLOR",
+		"BG_USER"       , _TL("User Defined"),
+		_TL(""),
+		g_pMaps->Get_Parameter("BG_USER")->asColor()
+	);
+
 	m_Parameters.Add_Bool("NODE_GENERAL",
-		"GOTO_NEWLAYER"	, _TL("Zoom to Added Layer"),
+		"GOTO_NEWLAYER" , _TL("Zoom to Added Layer"),
 		_TL(""),
 		g_pMaps->Get_Parameter("GOTO_NEWLAYER")->asBool()
 	);
 
 	m_Parameters.Add_Bool("NODE_GENERAL",
-		"SYNC_MAPS"		, _TL("Synchronize Map Extents"),
+		"SYNC_MAPS"     , _TL("Synchronize Map Extents"),
 		_TL(""),
 		false
 	);
 
 	m_Parameters.Add_Bool("NODE_GENERAL",
-		"CRS_CHECK"		, _TL("CRS Check"),
+		"CRS_CHECK"     , _TL("CRS Check"),
 		_TL("Perform a coordinate system compatibility check before a layer is added."),
 		g_pMaps->Get_Parameter("CRS_CHECK")->asBool()
 	);
 
 	//-----------------------------------------------------
 	m_Parameters.Add_Bool("NODE_GENERAL",
-		"GCS_POSITION"	, _TL("Position as Geographic Coordinates"),
+		"GCS_POSITION"  , _TL("Position as Geographic Coordinates"),
 		_TL("Display mouse position in status bar as geographic coordinates."),
 		false
 	);
 
 	//-----------------------------------------------------
 	m_Parameters.Add_Bool("NODE_GENERAL",
-		"SEL_EXTENT"	, _TL("Show Extent"),
+		"SEL_EXTENT"    , _TL("Show Extent"),
 		_TL("Display selected extent in map."),
 		false
 	);
 
 	m_Parameters.Add_Color("SEL_EXTENT",
-		"SEL_COLOUR"	, _TL("Colour"),
+		"SEL_COLOUR"    , _TL("Colour"),
 		_TL(""),
 		SG_GET_RGB(222, 222, 222)
 	);
 
 	m_Parameters.Add_Double("SEL_EXTENT",
-		"SEL_TRANSP"	, _TL("Transparency [%]"),
+		"SEL_TRANSP"    , _TL("Transparency [%]"),
 		_TL(""),
 		50., 0., true, 100., true
 	);
 
 	//-----------------------------------------------------
 	m_Parameters.Add_Bool("NODE_GENERAL",
-		"FRAME_SHOW"	, _TL("Frame"),
+		"FRAME_SHOW"    , _TL("Frame"),
 		_TL(""),
 		g_pMaps->Get_Parameter("FRAME_SHOW")->asBool()
 	);
 
 	m_Parameters.Add_Int("FRAME_SHOW",
-		"FRAME_WIDTH"	, _TL("Size"),
+		"FRAME_WIDTH"   , _TL("Size"),
 		_TL(""),
 		g_pMaps->Get_Parameter("FRAME_WIDTH")->asInt(), 10, true
 	);
 
 	m_Parameters.Add_Bool("FRAME_SHOW",
-		"FRAME_SCALE"	, _TL("Scale"),
+		"FRAME_SCALE"   , _TL("Scale"),
 		_TL("Displays the scale instead of coordinates in the bottom and left frame boxes, if there is no scale bar shown in the map."),
 		false
 	);
 
 	//-----------------------------------------------------
 	m_Parameters.Add_Bool("NODE_GENERAL",
-		"NORTH_SHOW"	, _TL("North Arrow"),
+		"NORTH_SHOW"    , _TL("North Arrow"),
 		_TL(""),
 		false
 	);
 
 	m_Parameters.Add_Double("NORTH_SHOW",
-		"NORTH_ANGLE"	, _TL("Direction"),
+		"NORTH_ANGLE"   , _TL("Direction"),
 		_TL(""),
 		0., -180., true, 360., true
 	);
 
 	m_Parameters.Add_Double("NORTH_SHOW",
-		"NORTH_SIZE"	, _TL("Size"),
+		"NORTH_SIZE"    , _TL("Size"),
 		_TL("Size given as percentage of map size"),
 		 5., 1., true, 100., true
 	);
@@ -494,20 +510,20 @@ void CWKSP_Map::On_Create_Parameters(void)
 	);
 
 	m_Parameters.Add_Bool("NORTH_SHOW",
-		"NORTH_EXTENT"	, _TL("Relate to Extent"),
+		"NORTH_EXTENT"  , _TL("Relate to Extent"),
 		_TL("Relate position and size to selected map extent."),
 		false
 	);
 
 	//-----------------------------------------------------
 	m_Parameters.Add_Bool("NODE_GENERAL",
-		"SCALE_SHOW"	, _TL("Scale Bar"),
+		"SCALE_SHOW"    , _TL("Scale Bar"),
 		_TL(""),
 		g_pMaps->Get_Parameter("SCALE_BAR")->asBool()
 	);
 
 	m_Parameters.Add_Choice("SCALE_SHOW",
-		"SCALE_STYLE"	, _TL("Style"),
+		"SCALE_STYLE"   , _TL("Style"),
 		_TL(""),
 		CSG_String::Format("%s|%s",
 			_TL("scale line"),
@@ -516,19 +532,19 @@ void CWKSP_Map::On_Create_Parameters(void)
 	);
 
 	m_Parameters.Add_Bool("SCALE_SHOW",
-		"SCALE_UNIT"	, _TL("Unit"),
+		"SCALE_UNIT"    , _TL("Unit"),
 		_TL(""),
 		true
 	);
 
 	m_Parameters.Add_Double("SCALE_SHOW",
-		"SCALE_WIDTH"	, _TL("Width"),
+		"SCALE_WIDTH"   , _TL("Width"),
 		_TL("Width given as percentage of map size"),
 		40., 1., true, 100., true
 	);
 
 	m_Parameters.Add_Double("SCALE_SHOW",
-		"SCALE_HEIGHT"	, _TL("Height"),
+		"SCALE_HEIGHT"  , _TL("Height"),
 		_TL("Height given as percentage of map size"),
 		 4., 0.1, true, 100., true
 	);
@@ -546,7 +562,7 @@ void CWKSP_Map::On_Create_Parameters(void)
 	);
 
 	m_Parameters.Add_Bool("SCALE_SHOW",
-		"SCALE_EXTENT"	, _TL("Relate to Extent"),
+		"SCALE_EXTENT"  , _TL("Relate to Extent"),
 		_TL("Relate position and size to selected map extent."),
 		false
 	);
@@ -576,6 +592,11 @@ int CWKSP_Map::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *
 {
 	if( Flags & PARAMETER_CHECK_ENABLE )
 	{
+		if(	pParameter->Cmp_Identifier("BG_COLOR") )
+		{
+			pParameter->Set_Children_Enabled(pParameter->asInt ());
+		}
+
 		if(	pParameter->Cmp_Identifier("SEL_EXTENT") )
 		{
 			pParameter->Set_Children_Enabled(pParameter->asBool());
@@ -883,8 +904,8 @@ CWKSP_Map_Layer * CWKSP_Map::Add_Layer(CWKSP_Layer *pLayer)
 
 		s += _TL("The coordinate system used by the layer is not identical with the one of the map!");
 		s += "\n";
-		s += wxString::Format("\n%s:\n  [%s]", _TL("Map"  ),                         m_Projection  .Get_Proj4().c_str());
-		s += wxString::Format("\n%s:\n  [%s]", _TL("Layer"), pLayer->Get_Object()->Get_Projection().Get_Proj4().c_str());
+		s += wxString::Format("\n%s:\n  [%s]", _TL("Map"  ),                         m_Projection  .Get_PROJ().c_str());
+		s += wxString::Format("\n%s:\n  [%s]", _TL("Layer"), pLayer->Get_Object()->Get_Projection().Get_PROJ().c_str());
 		s += "\n\n";
 		s += _TL("Do you want to activate on-the-fly projection for this layer in the map?");
 		s += "\n";
@@ -918,9 +939,14 @@ CWKSP_Map_Layer * CWKSP_Map::Add_Layer(CWKSP_Layer *pLayer)
 
 	if( Get_Count() == 1 )
 	{
-		if( pLayer->Get_Object() )
+		if( g_pMaps->Get_Parameter("NAMING")->asInt() == 1 && pLayer->Get_Object() )
 		{
 			m_Name = pLayer->Get_Object()->Get_Name();
+
+			if( m_Name.Length() > (size_t)g_pMaps->Get_Parameter("NAMING_LENGTH")->asInt() )
+			{
+				m_Name = m_Name.Left(g_pMaps->Get_Parameter("NAMING_LENGTH")->asInt() - 3) + "...";
+			}
 		}
 
 		m_Name.Prepend(g_pMaps->Get_Numbering());
@@ -1257,7 +1283,7 @@ void CWKSP_Map::Set_Synchronising(bool bOn)
 		m_Parameters("SYNC_MAPS")->Set_Value(bOn ? 1 : 0);
 	}
 
-	if( bOn )
+	if( bOn && m_Sync_bLock < 1 )
 	{
 		((CWKSP_Map_Manager *)Get_Manager())->Set_Extents(Get_Extent(), m_Projection);
 	}
@@ -1366,9 +1392,7 @@ void CWKSP_Map::Set_Projection(void)
 	{
 		CSG_Parameters P(*pTool->Get_Parameters());
 
-		P.Set_Parameter("CRS_PROJ4"    , m_Projection.Get_Proj4       ());
-		P.Set_Parameter("CRS_EPSG"     , m_Projection.Get_Authority_ID());
-		P.Set_Parameter("CRS_EPSG_AUTH", m_Projection.Get_Authority   ());
+		P.Set_Parameter("CRS_STRING"   , m_Projection.Get_WKT());
 
 		P.Add_Bool("", "ONTHEFLY", _TL("On-The-Fly Projection"),
 			_TL("Turn on the on-the-fly projection for all layers in the map."),
@@ -1380,10 +1404,7 @@ void CWKSP_Map::Set_Projection(void)
 		{
 			CSG_Projection Projection; CSG_Parameters &_P = *pTool->Get_Parameters();
 
-			if( _P["CRS_EPSG"].asInt() < 0 || !Projection.Create(_P["CRS_EPSG"].asInt(), _P["CRS_EPSG_AUTH"].asString()) )
-			{
-				Projection.Create(_P["CRS_PROJ4"].asString(), SG_PROJ_FMT_Proj4);
-			}
+			Projection.Create(_P["CRS_WKT"].asString());
 
 			if( P("ONTHEFLY")->asBool() )
 			{
@@ -1568,9 +1589,9 @@ CSG_Point CWKSP_Map::Get_World(wxRect rClient, wxPoint Point)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-#define MASK_R	254
-#define MASK_G	255
-#define MASK_B	255
+#define MASK_R 254
+#define MASK_G 255
+#define MASK_B 255
 
 //---------------------------------------------------------
 bool CWKSP_Map::Get_Image(wxImage &Image, const CSG_Grid_System &System)
@@ -2129,6 +2150,17 @@ bool CWKSP_Map::_Set_Thumbnail(void)
 }
 
 
+///////////////////////////////////////////////////////////
+//														 //
+///////////////////////////////////////////////////////////
+
+//---------------------------------------------------------
+wxColour CWKSP_Map::Get_Background(void)
+{
+	return( m_Parameters["BG_COLOR"].asInt() ? Get_Color_asWX(m_Parameters["BG_USER"].asInt()) : SYS_Get_Color_Background() );
+}
+
+
 ///////////////////////////////////////////////////////////
 //														 //
 ///////////////////////////////////////////////////////////
@@ -2142,47 +2174,54 @@ void CWKSP_Map::Draw_Map(wxDC &dc, double Zoom, const wxRect &rClient, int Flags
 //---------------------------------------------------------
 void CWKSP_Map::Draw_Map(wxDC &dc, const CSG_Rect &rWorld, double Zoom, const wxRect &rClient, int Flags, int Background)
 {
-	CWKSP_Map_DC	dc_Map(rWorld, rClient, Zoom, Background);
+	CSG_Map_DC dc_Map(rWorld, rClient, Zoom, Background >= 0 ? Background : Get_Background().GetRGB());
 
-	int	Flag_Labels	= !(Flags & LAYER_DRAW_FLAG_NOLABELS) ? 0 : LAYER_DRAW_FLAG_NOLABELS;
+	Draw_Map(dc_Map, Flags);
+
+	dc.DrawBitmap(dc_Map.Get_Bitmap(), rClient.GetLeft(), rClient.GetTop(), false);
+}
+
+//---------------------------------------------------------
+void CWKSP_Map::Draw_Map(CSG_Map_DC &dc, int Flags)
+{
+	int Flag_Labels = !(Flags & LAYER_DRAW_FLAG_NOLABELS) ? 0 : LAYER_DRAW_FLAG_NOLABELS;
 
-	//-----------------------------------------------------
 	for(int i=Get_Count()-1; i>=0; i--)
 	{
 		switch( Get_Item(i)->Get_Type() )
 		{
 		case WKSP_ITEM_Map_Layer:
-			{
-				CWKSP_Map_Layer     *pLayer	= (CWKSP_Map_Layer     *)Get_Item(i);
+		{
+			CWKSP_Map_Layer     *pLayer	= (CWKSP_Map_Layer     *)Get_Item(i);
 
-				if( pLayer->do_Show() )
-				{
-					pLayer->Draw(dc_Map, !(Flags & LAYER_DRAW_FLAG_NOEDITS) && pLayer->Get_Layer() == Get_Active_Layer() ? Flags : Flag_Labels);
-				}
+			if( pLayer->do_Show() )
+			{
+				pLayer->Draw(dc, !(Flags & LAYER_DRAW_FLAG_NOEDITS) && pLayer->Get_Layer() == Get_Active_Layer() ? Flags : Flag_Labels);
 			}
-			break;
+		}
+		break;
 
 		case WKSP_ITEM_Map_Graticule:
-			{
-				CWKSP_Map_Graticule *pLayer	= (CWKSP_Map_Graticule *)Get_Item(i);
+		{
+			CWKSP_Map_Graticule *pLayer	= (CWKSP_Map_Graticule *)Get_Item(i);
 
-				if( pLayer->do_Show() )//&& pLayer->Get_Graticule(Get_Extent()) )
-				{
-					pLayer->Draw(dc_Map);
-				}
+			if( pLayer->do_Show() )//&& pLayer->Get_Graticule(Get_Extent()) )
+			{
+				pLayer->Draw(dc);
 			}
-			break;
+		}
+		break;
 
 		case WKSP_ITEM_Map_BaseMap:
-			{
-				CWKSP_Map_BaseMap   *pLayer	= (CWKSP_Map_BaseMap   *)Get_Item(i);
+		{
+			CWKSP_Map_BaseMap   *pLayer	= (CWKSP_Map_BaseMap   *)Get_Item(i);
 
-				if( pLayer->do_Show() )
-				{
-					pLayer->Draw(dc_Map);
-				}
+			if( pLayer->do_Show() )
+			{
+				pLayer->Draw(dc);
 			}
-			break;
+		}
+		break;
 
 		default:
 			break;
@@ -2190,12 +2229,9 @@ void CWKSP_Map::Draw_Map(wxDC &dc, const CSG_Rect &rWorld, double Zoom, const wx
 	}
 
 	//-----------------------------------------------------
-	Draw_Extent     (dc_Map, rWorld, rClient);
-	Draw_ScaleBar   (dc_Map, rWorld, rClient);
-	Draw_North_Arrow(dc_Map, rWorld, rClient);
-
-	//-----------------------------------------------------
-	dc_Map.Draw(dc);
+	Draw_Extent     (dc);
+	Draw_ScaleBar   (dc);
+	Draw_North_Arrow(dc);
 }
 
 //---------------------------------------------------------
@@ -2288,65 +2324,64 @@ bool CWKSP_Map::Draw_Legend(wxDC &dc, double Zoom_Map, double Zoom, wxPoint Posi
 //---------------------------------------------------------
 bool CWKSP_Map::Get_Legend_Size(wxSize &Size, double Zoom_Map, double Zoom)
 {
-	wxBitmap	bmp(10, 10);
-	wxMemoryDC	dc(bmp);
+	wxBitmap bmp(10, 10); wxMemoryDC dc(bmp);
 
 	return( Draw_Legend(dc, Zoom_Map, Zoom, wxPoint(0, 0), &Size) );
 }
 
 //---------------------------------------------------------
-bool CWKSP_Map::Draw_North_Arrow(CWKSP_Map_DC &dc_Map, const CSG_Rect &rWorld, const wxRect &rClient)
+bool CWKSP_Map::Draw_North_Arrow(CSG_Map_DC &dc)
 {
 	if( !m_Parameters("NORTH_SHOW")->asBool() )
 	{
 		return( true );
 	}
 
-	const double	Arrow[3][2]	= { { 0., 1. }, { 0.5, -1. }, { 0., -0.5 } };
+	const double Arrow[3][2] = { { 0., 1. }, { 0.5, -1. }, { 0., -0.5 } };
 
-	wxRect	r	= !m_Parameters("NORTH_EXTENT")->asBool() ? wxRect(0, 0, rClient.GetWidth(), rClient.GetHeight()) : wxRect(
-		(int)(dc_Map.xWorld2DC   (Get_Extent().Get_XMin  ())),
-		(int)(dc_Map.yWorld2DC   (Get_Extent().Get_YMax  ())),
-		(int)(dc_Map.m_World2DC * Get_Extent().Get_XRange()),
-		(int)(dc_Map.m_World2DC * Get_Extent().Get_YRange())
+	wxRect r = !m_Parameters("NORTH_EXTENT")->asBool() ? wxRect(dc.rDC()) : wxRect(
+		(int)(dc.xWorld2DC    (Get_Extent().Get_XMin  ())),
+		(int)(dc.yWorld2DC    (Get_Extent().Get_YMax  ())),
+		(int)(dc. World2DC() * Get_Extent().Get_XRange()),
+		(int)(dc. World2DC() * Get_Extent().Get_YRange())
 	);
 
-	double	cos_a	= cos(-m_Parameters("NORTH_ANGLE")->asDouble() * M_DEG_TO_RAD);
-	double	sin_a	= sin(-m_Parameters("NORTH_ANGLE")->asDouble() * M_DEG_TO_RAD);
-	double	scale	= m_Parameters("NORTH_SIZE")->asDouble() * 0.01 * M_GET_MIN(r.GetWidth(), r.GetHeight());
+	double cos_a = cos(-m_Parameters("NORTH_ANGLE")->asDouble() * M_DEG_TO_RAD);
+	double sin_a = sin(-m_Parameters("NORTH_ANGLE")->asDouble() * M_DEG_TO_RAD);
+	double scale = m_Parameters("NORTH_SIZE")->asDouble() * 0.01 * M_GET_MIN(r.GetWidth(), r.GetHeight());
 
-	int		xOff	= r.GetX() + (int)(0.5 +                 m_Parameters("NORTH_OFFSET_X")->asDouble() * 0.01 * r.GetWidth ());
-	int		yOff	= r.GetY() + (int)(0.5 + r.GetHeight() - m_Parameters("NORTH_OFFSET_Y")->asDouble() * 0.01 * r.GetHeight());
+	int xOff = r.GetX() + (int)(0.5 +                 m_Parameters("NORTH_OFFSET_X")->asDouble() * 0.01 * r.GetWidth ());
+	int yOff = r.GetY() + (int)(0.5 + r.GetHeight() - m_Parameters("NORTH_OFFSET_Y")->asDouble() * 0.01 * r.GetHeight());
 
 	for(int side=0; side<=1; side++)
 	{
-		wxPoint	Points[3];
+		wxPoint Points[3];
 
 		for(int i=0; i<3; i++)
 		{
-			double	x	= scale * Arrow[i][0] * (side ? 1 : -1);
-			double	y	= scale * Arrow[i][1];
+			double x = scale * Arrow[i][0] * (side ? 1 : -1);
+			double y = scale * Arrow[i][1];
 
-			Points[i].x	= xOff + (int)(0.5 + cos_a * x - sin_a * y);
-			Points[i].y	= yOff - (int)(0.5 + sin_a * x + cos_a * y);
+			Points[i].x = xOff + (int)(0.5 + cos_a * x - sin_a * y);
+			Points[i].y = yOff - (int)(0.5 + sin_a * x + cos_a * y);
 		}
 
 		if( side == 0 )
 		{
-		//	dc_Map.dc.SetPen     (wxPen  (*wxWHITE, 3));
-		//	dc_Map.dc.DrawLines  (3, Points);
+		//	dc.SetPen     (wxPen  (*wxWHITE, 3));
+		//	dc.DrawLines  (3, Points);
 
-			dc_Map.dc.SetPen     (wxPen  (*wxBLACK, 0));
-			dc_Map.dc.SetBrush   (wxBrush(*wxBLACK));
-			dc_Map.dc.DrawPolygon(3, Points);
-            dc_Map.dc.DrawPolygon(3, Points);
+			dc.SetPen     (wxPen  (*wxBLACK, 0));
+			dc.SetBrush   (wxBrush(*wxBLACK));
+			dc.DrawPolygon(3, Points);
+            dc.DrawPolygon(3, Points);
 		}
 		else
 		{
-			dc_Map.dc.SetPen     (wxPen  (*wxBLACK, 0));
-			dc_Map.dc.SetBrush   (wxBrush(*wxWHITE));
-			dc_Map.dc.DrawPolygon(3, Points);
-		//	dc_Map.dc.DrawLines  (3, Points);
+			dc.SetPen     (wxPen  (*wxBLACK, 0));
+			dc.SetBrush   (wxBrush(*wxWHITE));
+			dc.DrawPolygon(3, Points);
+		//	dc.DrawLines  (3, Points);
 		}
 	}
 
@@ -2354,86 +2389,87 @@ bool CWKSP_Map::Draw_North_Arrow(CWKSP_Map_DC &dc_Map, const CSG_Rect &rWorld, c
 }
 
 //---------------------------------------------------------
-bool CWKSP_Map::Draw_ScaleBar(CWKSP_Map_DC &dc_Map, const CSG_Rect &rWorld, const wxRect &rClient)
+bool CWKSP_Map::Draw_ScaleBar(CSG_Map_DC &dc)
 {
 	if( !is_ScaleBar() )
 	{
 		return( true );
 	}
 
-	double	dWidth	= 0.01 * m_Parameters("SCALE_WIDTH")->asDouble();
+	double dWidth = 0.01 * m_Parameters("SCALE_WIDTH")->asDouble();
 
-	wxRect	r	= !m_Parameters("SCALE_EXTENT")->asBool() ? wxRect(0, 0, rClient.GetWidth(), rClient.GetHeight()) : wxRect(
-		(int) dc_Map .xWorld2DC  (Get_Extent().Get_XMin  ()),
-		(int) dc_Map .yWorld2DC  (Get_Extent().Get_YMax  ()),
-		(int)(dc_Map.m_World2DC * Get_Extent().Get_XRange()),
-		(int)(dc_Map.m_World2DC * Get_Extent().Get_YRange())
+	wxRect r = !m_Parameters("SCALE_EXTENT")->asBool() ? wxRect(dc.rDC()) : wxRect(
+		(int) dc.xWorld2DC    (Get_Extent().Get_XMin  ()),
+		(int) dc.yWorld2DC    (Get_Extent().Get_YMax  ()),
+		(int)(dc. World2DC() * Get_Extent().Get_XRange()),
+		(int)(dc. World2DC() * Get_Extent().Get_YRange())
 	);
 
-	r	= wxRect(
+	r = wxRect(
 		(int)(0.5 + r.GetWidth () * 0.01 * m_Parameters("SCALE_OFFSET_X")->asDouble()) + r.GetX(), r.GetY() + r.GetHeight() -
 		(int)(0.5 + r.GetHeight() * 0.01 * m_Parameters("SCALE_OFFSET_Y")->asDouble()),
 		(int)(0.5 + r.GetWidth () * dWidth),
 		(int)(0.5 + r.GetHeight() * 0.01 * m_Parameters("SCALE_HEIGHT"  )->asDouble())
 	);
 
-	dWidth	= dc_Map.m_DC2World * r.GetWidth();
+	dWidth = dc.DC2World() * r.GetWidth();
 
-	CSG_String	Unit;
+	CSG_String Unit;
 
 	if( m_Projection.is_Okay() && m_Parameters("SCALE_UNIT")->asBool() )
 	{
-		Unit	= SG_Get_Projection_Unit_Name(m_Projection.Get_Unit(), true);
+		Unit = CSG_Projections::Get_Unit_Name(m_Projection.Get_Unit(), true);
 
-		if( Unit.is_Empty() )	Unit	= m_Projection.Get_Unit_Name();
+		if( Unit.is_Empty() ) Unit = m_Projection.Get_Unit_Name();
 
-		if( m_Projection.Get_Unit() == SG_PROJ_UNIT_Meter && dWidth > 10000. )
+		if( m_Projection.Get_Unit() == ESG_Projection_Unit::Meter && dWidth > 10000. )
 		{
-			Unit	 = SG_Get_Projection_Unit_Name(SG_PROJ_UNIT_Kilometer, true);
-			dWidth	/= 1000.;
+			dWidth /= 1000.; Unit = CSG_Projections::Get_Unit_Name(ESG_Projection_Unit::Kilometer, true);
 		}
 	}
 
-	int	Style	= SCALE_STYLE_LINECONN|SCALE_STYLE_GLOOMING;
+	int Style = SCALE_STYLE_LINECONN|SCALE_STYLE_GLOOMING;
 
 	if( m_Parameters("SCALE_STYLE")->asInt() == 1 )
-		Style	|= SCALE_STYLE_BLACKWHITE;
+	{
+		Style |= SCALE_STYLE_BLACKWHITE;
+	}
 
-	Draw_Scale(dc_Map.dc, r, 0., dWidth, SCALE_HORIZONTAL, SCALE_TICK_TOP, Style, Unit.c_str());
+	Draw_Scale(dc.Get_DC(), r, 0., dWidth, SCALE_HORIZONTAL, SCALE_TICK_TOP, Style, Unit.c_str());
 
 	return( true );
 }
 
 //---------------------------------------------------------
-bool CWKSP_Map::Draw_Extent(CWKSP_Map_DC &dc_Map, const CSG_Rect &rWorld, const wxRect &rClient)
+bool CWKSP_Map::Draw_Extent(CSG_Map_DC &dc)
 {
-	if( !m_Parameters("SEL_EXTENT")->asBool() || rWorld == Get_Extent() )
+	if( !m_Parameters("SEL_EXTENT")->asBool() || dc.rWorld() == Get_Extent() )
 	{
 		return( true );
 	}
 
-	if( dc_Map.IMG_Draw_Begin(m_Parameters("SEL_TRANSP")->asDouble() / 100.) )
+	if( dc.Draw_Image_Begin(m_Parameters("SEL_TRANSP")->asDouble() / 100.) )
 	{
-		int	Colour	= m_Parameters("SEL_COLOUR")->asColor();
+		int Color = m_Parameters("SEL_COLOUR")->asColor();
 
-		wxRect	r(0, 0, rClient.GetWidth(), rClient.GetHeight()); r.Inflate(1);
+		wxRect r(dc.rDC()); r.Inflate(1);
 
-		if( rWorld.Get_XRange() > Get_Extent().Get_XRange() )
+		if( dc.rWorld().Get_XRange() > Get_Extent().Get_XRange() )
 		{
-			int	d	= (int)(0.5 + dc_Map.m_World2DC * (rWorld.Get_XRange() - Get_Extent().Get_XRange()) / 2.);
+			int d = (int)(0.5 + dc.World2DC() * (dc.rWorld().Get_XRange() - Get_Extent().Get_XRange()) / 2.);
 
-			dc_Map.IMG_Set_Rect(r.GetLeft (), r.GetTop(), r.GetLeft () + d, r.GetBottom(), Colour);
-			dc_Map.IMG_Set_Rect(r.GetRight(), r.GetTop(), r.GetRight() - d, r.GetBottom(), Colour);
+			dc.Draw_Image_Pixels(r.GetLeft (), r.GetTop(), r.GetLeft () + d, r.GetBottom(), Color);
+			dc.Draw_Image_Pixels(r.GetRight(), r.GetTop(), r.GetRight() - d, r.GetBottom(), Color);
 		}
 		else
 		{
-			int	d	= (int)(0.5 + dc_Map.m_World2DC * (rWorld.Get_YRange() - Get_Extent().Get_YRange()) / 2.);
+			int d = (int)(0.5 + dc.World2DC() * (dc.rWorld().Get_YRange() - Get_Extent().Get_YRange()) / 2.);
 
-			dc_Map.IMG_Set_Rect(r.GetLeft(), r.GetTop   (), r.GetRight(), r.GetTop   () + d, Colour);
-			dc_Map.IMG_Set_Rect(r.GetLeft(), r.GetBottom(), r.GetRight(), r.GetBottom() - d, Colour);
+			dc.Draw_Image_Pixels(r.GetLeft(), r.GetTop   (), r.GetRight(), r.GetTop   () + d, Color);
+			dc.Draw_Image_Pixels(r.GetLeft(), r.GetBottom(), r.GetRight(), r.GetBottom() - d, Color);
 		}
 
-		dc_Map.IMG_Draw_End();
+		dc.Draw_Image_End();
 	}
 
 	return( true );
@@ -2453,11 +2489,11 @@ void CWKSP_Map::Show_Coordinate(const CSG_Point &Coordinate) const
 	{
 		TSG_Point	Degree(Coordinate);
 
-		if( m_Projection.is_Geographic() || SG_Get_Projected(m_Projection, CSG_Projections::Get_GCS_WGS84(), Degree) )
+		if( m_Projection.is_Geographic() || SG_Get_Projected(m_Projection, CSG_Projection::Get_GCS_WGS84(), Degree) )
 		{
 			if( !m_Projection.is_Geographic() )
 			{
-				P.Add_Node("", "MAP", m_Projection.Get_Name(), m_Projection.Get_Proj4());
+				P.Add_Node("", "MAP", m_Projection.Get_Name(), m_Projection.Get_PROJ());
 				P.Add_Info_Value("MAP", "MAP_X", _TL("Easting" ), _TL(""), PARAMETER_TYPE_Double, Coordinate.x);
 				P.Add_Info_Value("MAP", "MAP_Y", _TL("Northing"), _TL(""), PARAMETER_TYPE_Double, Coordinate.y);
 			}
